/* global wp, jQuery */
/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	});
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	});
	// blog description
	wp.customize( 'blogdescription_option', function( value ) {
		value.bind(function(to) {
			if( to ) {
				$( '.site-description' ).css( {
					clip: 'auto',
					position: 'relative',
				} );
			} else {
				$( '.site-description' ).css( {
					clip: 'rect(1px, 1px, 1px, 1px)',
					position: 'absolute',
				} );
			}
		})
	});

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title' ).css( {
					clip: 'rect(1px, 1px, 1px, 1px)',
					position: 'absolute',
				} );
			} else {
				$( '.site-title' ).css( {
					clip: 'auto',
					position: 'relative',
				} );
				$( '.site-title a, .site-description' ).css( {
					color: to,
				} );
			}
		} );
	});

	// header hover text color
	wp.customize( 'header_hover_textcolor', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a:hover' ).css( {
				color: to,
			});
		} );
	});

	// header search icon color
	wp.customize( 'header_search_toggle_color_group', function( value ) {
		value.bind( function( to ) {
			if(to.color) {
				$( "header .header-wrapper .header__icon-group #search" ).css({
					color: to.color
				})
			} else {
				$( "header .header-wrapper .header__icon-group #search" ).css({
					color: 'initial'
				})
			}
			if(to.hover) {
				$( "header .header-wrapper .header__icon-group #search" ).attr( "onmouseover", "this.style.color='" + to.hover + "'" )
			} else {
				$( "header .header-wrapper .header__icon-group #search" ).removeAttr( "onmouseover" )
			}
		} );
	});
	
	// ajax load more button
	wp.customize( 'archive_ajax_button_label', function( value ) {
		value.bind( function( to ) {
			$( '.the-styled-blog-load-more' ).text( to );
		} );
	});
}( jQuery ) );
