/**
 * Main theme scripts
 * 
 * @package The Styled Blog
 * @since 1.0.0
 * 
 */
jQuery(document).ready(function($) {
    const slideArrow = {
      nextArrow: `<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>`,
      prevArrow: `<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>`,
    };
    const slideArrowText = {
      nextArrow: `<button type="button" class="slick-next">Next</i></button>`,
      prevArrow: `<button type="button" class="slick-prev">Prev</button>`,
    };
    let isOpened = false;
    let $searchBox = $("#search-box");
    $("#search").on("click", function (e) {
      e.preventDefault();
      if (!isOpened) {
        $searchBox.slideDown();
        isOpened = true;
        $(this).addClass("active");
      } else {
        $searchBox.slideUp();
        isOpened = false;
        $(this).removeClass("active");
      }
    });
    clickOutSideElm($("header"), function () {
      $searchBox.slideUp();
      isOpened = false;
      $("#search").removeClass("active");
    });

    function clickOutSideElm(elm, callback) {
      $(document).mouseup(function (e) {
        var container = $(elm);
        if (!container.is(e.target) && container.has(e.target).length === 0) {
          callback();
        }
      });
    }
    
    /**
     * Masonry Layout
     */
    let $masonry = $(".blog-masonry").masonry({
      itemSelector: ".post-card",
      horizontalOrder: true,
      gutter: 30,
    });
    $masonry.imagesLoaded().progress(function () {
      $masonry.masonry("layout");
    });

    // featured links carousel
    var featuredSection = $( "#the-styled-blog-featured-section" )
    if( featuredSection.length > 0 ) {
      var column
      if( featuredSection.data( "column" ) == 'three' ) { column = 3 } else { column = 2 }
      var featuredItems = featuredSection.find( ".categories-wrap" )
      featuredItems.slick(Object.assign({
          dots: false,
          arrows: true,
          infinite: false,
          autoplay: false,
          slidesToShow: column,
          responsive: [
              {
                breakpoint: 1024,
                settings: {
                  slidesToShow: 2,
                },
              },
              {
                breakpoint: 768,
                settings: {
                  slidesToShow: 1,
                },
              },
            ],
        }, slideArrow));
    }

    // banner slider layout one
    $(".blog-ocean__slider.layout-one").each(function() {
      var _this = $(this),
      fade = ( _this.data( "fade" ) == 1 );
      speed = _this.data( "speed" );
      const bannerOneSlide = _this.slick(Object.assign({
        dots: false,
        infinite: false,
        fade: fade,
        speed: speed,
        arrows: true,
        autoplay: false
      }, slideArrowText));

      _this.on( "click", ".banner-next-post", function() {
        bannerOneSlide.slick('slickNext')
      })
    })

    /**
     * Frontpage sections blocks "gallery post format" slider 
     * 
     * 
     */
     var galleryFormatWrapper;
     if($( "body.archive" ).length ) {
       galleryFormatWrapper = $( "body.archive" )
     } else if($( "body.blog" ).length ) {
       galleryFormatWrapper = $( "body.blog" )
     } else if($( "body.home.blog" ).length ) {
       galleryFormatWrapper = $( "body.home.blog" )
     } else {
       galleryFormatWrapper = false;
     }
     if(galleryFormatWrapper) {
        galleryFormatWrapper.each(function() {
        var sectionContainer  = $(this),
        sectionWrapper = sectionContainer.find( ".format-gallery .wp-block-gallery ul, .format-gallery .wp-block-gallery.has-nested-images" ), innerSectionContainer
        if(sectionWrapper.length) {
          sectionWrapper.each(function() {
            innerSectionContainer = $(this)
            innerSectionContainer.slick(Object.assign(
              slideArrow
            ))
          })
        }
      })
    }

    /**
     * Back To Top script
     * 
     */
    if( $( "#the-styled-blog-scroll-to-top" ).length ) {
      var scrollContainer = $( "#the-styled-blog-scroll-to-top" );
      $(window).scroll(function() {
        if ( $(this).scrollTop() > 800 ) {
          scrollContainer.addClass('show');
        } else {
          scrollContainer.removeClass('show');
        }
      });
      scrollContainer.click(function( event ) {
        event.preventDefault();
        // Animate the scrolling motion.
        jQuery("html, body").animate({
          scrollTop:0
        },"slow");
      });
    }
    
    /**
     * Header Toggle Sidebar handler
     * 
     */
    var header_sidebar_trigger = $( ".header-sidebar-trigger" )
    if( header_sidebar_trigger.length ) {
        header_sidebar_trigger.on( "click", function() {
            $("#page").prepend( '<div class="header-sidebar-overlay"></div>');
            $("body").toggleClass( "header_toggle_sidebar_active" );
            $(this).parent().next(".header-sidebar-content").animate({
              width: "toggle"
            });
        })

        // on close trigger
        $(document).on( "click", ".header-sidebar-content .header-sidebar-trigger-close, .header-sidebar-overlay", function() {
            $("body").toggleClass( "header_toggle_sidebar_active" );
            $("#page .header-sidebar-overlay").remove();
            $("body").find( ".header-sidebar-content" ).animate({
                width: "toggle"
            })
        })
    }

    /**
     * Ajax load more in archive pages
     * 
     * 
     */
     if( theStyledBlogObject.ajaxPostsLoad ) {
      var _wpnonce, ajaxUrl, paged, query_vars;
      _wpnonce    = theStyledBlogObject._wpnonce;
      ajaxUrl     = theStyledBlogObject.ajaxUrl;
      paged       = ( parseInt( theStyledBlogObject.paged ) === 0 ) ? parseInt( theStyledBlogObject.paged ) + 1 : parseInt( theStyledBlogObject.paged );
      query_vars  = theStyledBlogObject.query_vars;
      currentPage = theStyledBlogObject.currentPage;
      /**
       * Ajax post loader
       * 
       */
      $(document).on( "click", ".the-styled-blog-load-more", function() {
          var _this = $(this), parentElement = _this.parent().siblings( '#primary' )
          $.ajax({
              method: 'POST',
              url: ajaxUrl,
              data: {
                  'action'  : 'the_styled_blog_load_query_posts',
                  '_wpnonce': _wpnonce,
                  'query_vars' : JSON.stringify( query_vars ),
                  'paged'      : paged + 1,
                  'currentPage': currentPage
              },
              beforeSend: function() {
                  parentElement.addClass( 'retrieving-posts' );
                  _this.text('Loading.....');
              },
              success: function(response) {
                  var parsedRes = JSON.parse(response)
                  if( parsedRes.loaded ) {
                      console.log( 'Posts loaded' );
                  }
                  parentElement.removeClass( 'retrieving-posts' );
                  parentElement.append( parsedRes.posts );
                  if( parsedRes.continue ) {
                      _this.text( theStyledBlogObject.ajaxPostsLoadText );
                      paged++;
                  } else {
                    _this.parent().remove()
                  }
              },
              complete: function() {
                // reinit masonry layouts
                $masonry.masonry( 'destroy' )
                $(".blog-masonry").masonry({
                  itemSelector: ".post-card",
                  horizontalOrder: true,
                  gutter: 30,
                });
              }
          })
      })
    }

    /**
     * Sticky sidebar
     * 
     */
    if( theStyledBlogObject.stickySidebar ) {
      $( ".primary-section, .secondary-section" ).theiaStickySidebar({'minWidth':1024})
    }

    /**
     * Sticky header
     * 
     */
    if( theStyledBlogObject.stickyHeader ) {
      $('#content').waypoint(function(direction) {  
            $('header.theme-default').toggleClass('fixed_header');
        }, { offset: + 0 });
    }
});
