<?php
/**
 * The Styled Blog Theme Customizer
 *
 * @package The Styled Blog
 */
function the_styled_blog_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_section( 'header_image' )->priority		= 10;
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_section( 'title_tagline' )->panel = 'the_styled_blog_site_identity_panel';
	$wp_customize->get_section( 'title_tagline' )->title = esc_html__( 'Logo & Site Icon', 'the-styled-blog' );

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'the_styled_blog_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'the_styled_blog_customize_partial_blogdescription',
			)
		);
		// ajax load more 
		$wp_customize->selective_refresh->add_partial(
			'archive_ajax_button_label',
			array(
				'selector'        => '.the-styled-blog-load-more',
				'render_callback' => 'the_styled_blog_customize_partial_aja_load_more',
			)
		);
	}
	require get_template_directory() . '/inc/customizer/custom-controls/repeater/repeater.php';
	require get_template_directory() . '/inc/customizer/roots.php';
	require get_template_directory() . '/inc/customizer/custom-controls/radio-image/radio-image.php';
	require get_template_directory() . '/inc/customizer/custom-controls/section-heading/section-heading.php';
	require get_template_directory() . '/inc/customizer/custom-controls/typography/typography.php';
	require get_template_directory() . '/inc/customizer/custom-controls/redirect-control/redirect-control.php';
	require get_template_directory() . '/inc/customizer/custom-controls/tab-control/tab-control.php';

	// register control type
	$wp_customize->register_control_type( 'The_Styled_Blog_WP_Radio_Image_Control' );
	$wp_customize->register_control_type( 'The_Styled_Blog_WP_Typography_Control' );

	/**
	 * Register "Site Identity Options" panel
	 * 
	 */
	$wp_customize->add_panel( 'the_styled_blog_site_identity_panel', array(
		'title' => esc_html__( 'Site Identity', 'the-styled-blog' ),
		'priority' => 5
	));

	/**
	 * Register "Gloabl Options" panel
	 * 
	 */
	$wp_customize->add_panel( 'the_styled_blog_global_options_panel', array(
		'title' => esc_html__( 'Global Options', 'the-styled-blog' ),
		'priority' => 10
	));

	/**
	 * Register "Theme Header" panel
	 * 
	 */
	$wp_customize->add_panel( 'the_styled_blog_header_panel', array(
		'title' => esc_html__( 'Theme Header', 'the-styled-blog' ),
		'priority' => 20
	));

	/**
	 * Register "Frontpage Sections" panel
	 * 
	 */
	$wp_customize->add_panel( 'the_styled_blog_frontpage_sections_panel', array(
		'title' => esc_html__( 'Frontpage Sections', 'the-styled-blog' ),
		'priority' => 30
	));
	
	/**
	 * Register "Theme Footer" panel
	 * 
	 */
	$wp_customize->add_panel( 'the_styled_blog_footer_panel', array(
		'title' => esc_html__( 'Theme Footer', 'the-styled-blog' ),
		'priority' => 80
	));

	/**
	 * Theme Color
	 * 
	 */
	$wp_customize->add_setting( 'the_styled_blog_theme_color', array(
		'sanitize_callback' => 'sanitize_hex_color'
	) );

	$wp_customize->add_control( 
		new WP_Customize_Color_Control( $wp_customize, 'the_styled_blog_theme_color', array(
			'label'      => esc_html__( 'Theme Color', 'the-styled-blog' ),
			'section'    => 'colors',
			'settings'   => 'the_styled_blog_theme_color'
		))
	);

	/**
	 * Theme Hover Color
	 * 
	 */
	$wp_customize->add_setting( 'the_styled_blog_theme_hover_color', array(
		'default' => '#717171',
		'sanitize_callback' => 'sanitize_hex_color'
	) );

	$wp_customize->add_control( 
		new WP_Customize_Color_Control( $wp_customize, 'the_styled_blog_theme_hover_color', array(
			'label'      => esc_html__( 'Theme Hover Color', 'the-styled-blog' ),
			'section'    => 'colors',
			'settings'   => 'the_styled_blog_theme_hover_color'
		))
	);

	/**
	 * Widget Title Color
	 * 
	 */
	$wp_customize->add_setting( 'the_styled_blog_widget_title_color', array(
		'default' => '#000000',
		'sanitize_callback' => 'sanitize_hex_color'
	) );

	$wp_customize->add_control( 
		new WP_Customize_Color_Control( $wp_customize, 'the_styled_blog_widget_title_color', array(
			'label'      => esc_html__( 'Widget Title Color', 'the-styled-blog' ),
			'section'    => 'colors',
			'settings'   => 'the_styled_blog_widget_title_color'
		))
	);

	/**
	 * Footer Newsletter section
	 * 
	 * @since 1.0.0
	 */
	$wp_customize->add_section( 'footer_newsletter_section', array(
		'title' => esc_html__( 'Footer Newsletter', 'the-styled-blog' ),
		'priority'  => 50
	));

	// theme documentation info box
	$wp_customize->add_setting( 'site_newsletter_info', array(
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control( 
		new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_newsletter_info', array(
			'label'	      => esc_html__( 'For newsletter section', 'the-styled-blog' ),
			'description' => esc_html__( 'Shortcode field, text color, hover color and background colors , gradient colors and padding option in pro', 'the-styled-blog' ),
			'section'     => 'footer_newsletter_section',
			'settings'    => 'site_newsletter_info',
			'choices' => array(
				array(
					'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                    'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
				)
			)
		))
	);

	/**
	 * Footer Instagram section
	 * 
	 * @since 1.0.0
	 */
	$wp_customize->add_section( 'footer_instagram_section', array(
		'title' => esc_html__( 'Footer Instagram', 'the-styled-blog' ),
		'priority'  => 50
	));

	// theme documentation info box
	$wp_customize->add_setting( 'site_instagram_info', array(
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control( 
		new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_instagram_info', array(
			'label'	      => esc_html__( 'For instagram section', 'the-styled-blog' ),
			'description' => esc_html__( 'Shortcode field, text color, hover color and background colors , gradient colors and padding option in pro', 'the-styled-blog' ),
			'section'     => 'footer_instagram_section',
			'settings'    => 'site_instagram_info',
			'choices' => array(
				array(
					'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                    'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
				)
			)
		))
	);
}
add_action( 'customize_register', 'the_styled_blog_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function the_styled_blog_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function the_styled_blog_customize_partial_blogdescription() {
	bloginfo( 'description' );
}


// render ajax load more button label
function the_styled_blog_customize_partial_aja_load_more() {
	return get_theme_mod( 'archive_ajax_button_label' );
}
/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function the_styled_blog_customize_preview_js() {
	wp_enqueue_script( 'the-styled-blog-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), THE_STYLED_BLOG_VERSION, true );
}
add_action( 'customize_preview_init', 'the_styled_blog_customize_preview_js' );

/**
 * Binds JS handlers to extend Theme Customizer (section inside section).
 */
function the_styled_blog_customize_controls_scripts() {
    wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/lib/fontawesome/css/all.min.css', array(), '5.15.3', 'all' );
    wp_enqueue_style( 'select-2', get_template_directory_uri() . '/assets/lib/select2/css/select2.min.css', array(), '4.1.0', 'all' );
    wp_enqueue_style( 'the-styled-blog-customizer-control', get_template_directory_uri() . '/inc/customizer/assets/customizer-controls.css', array(), THE_STYLED_BLOG_VERSION, 'all' );
    wp_enqueue_script( 'select-2', get_template_directory_uri() . '/assets/lib/select2/js/select2.min.js', array(), '4.1.0', true );
    wp_enqueue_script( 'the-styled-blog-customizer-control', get_template_directory_uri() . '/inc/customizer/assets/customizer-controls.min.js', array( 'react', 'wp-blocks', 'wp-editor', 'wp-element', 'wp-i18n', 'wp-polyfill', 'wp-components' ), THE_STYLED_BLOG_VERSION, true );
    wp_set_script_translations( 'the-styled-blog-customizer-control', 'the-styled-blog' );
}
add_action( 'customize_controls_enqueue_scripts', 'the_styled_blog_customize_controls_scripts' );

// include files
require get_template_directory() . '/inc/customizer/sanitize.php';
require get_template_directory() . '/inc/customizer/sections/about-theme.php';
require get_template_directory() . '/inc/customizer/sections/site-identity.php';
require get_template_directory() . '/inc/customizer/sections/global-options.php';
require get_template_directory() . '/inc/customizer/sections/theme-header.php';
require get_template_directory() . '/inc/customizer/sections/main-banner.php';
require get_template_directory() . '/inc/customizer/sections/featured-links.php';
require get_template_directory() . '/inc/customizer/sections/blog-archive.php';
require get_template_directory() . '/inc/customizer/sections/single-post.php';
require get_template_directory() . '/inc/customizer/sections/three-column.php';
require get_template_directory() . '/inc/customizer/sections/products-section.php';
require get_template_directory() . '/inc/customizer/sections/theme-footer.php';
require get_template_directory() . '/inc/customizer/sections/sidebar-layouts.php';

if ( ! function_exists( 'the_styled_blog_get_google_font_weight_html' ) ) :
    /**
     * get Google font weights html
     *
     * @since 1.0.0
     */
    function the_styled_blog_get_google_font_weight_html() {
		$google_fonts_file = get_template_directory() . '/assets/lib/googleFonts.json';
		$google_fonts = array();
		if ( file_exists( $google_fonts_file ) ) {
            $google_fonts   = json_decode( file_get_contents( $google_fonts_file ), true );
		}
		$font_family = isset( $_REQUEST['font_family'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['font_family'] ) ) : esc_html( 'DM Sans' );
		$font_weights = $google_fonts[$font_family]['variants']['normal'];

        $options_array = '';
        foreach ( $font_weights as $weight_key => $weight ) {
		?>
            <option value="<?php echo esc_attr( $weight_key ); ?>"><?php echo esc_html( $weight_key ); ?></option>
		<?php
		}
        wp_die();
    }
endif;
add_action( "wp_ajax_the_styled_blog_get_google_font_weight_html", "the_styled_blog_get_google_font_weight_html" );