<?php
/**
 * About Theme Panel
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
if( !function_exists( 'the_styled_blog_customizer_about_theme_panel' ) ) :
    /**
     * Register blog archive section settings
     * 
     */
    function the_styled_blog_customizer_about_theme_panel( $wp_customize ) {
        /**
         * About theme section
         * 
         * @since 1.0.0
         */
        $wp_customize->add_section( 'the_styled_blog_about_section', array(
            'title' => esc_html__( 'About Theme', 'the-styled-blog' ),
            'priority'  => 1
        ));
        
        // theme documentation info box
        $wp_customize->add_setting( 'site_documentation_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_documentation_info', array(
                'label'	      => esc_html__( 'Theme Documentation', 'the-styled-blog' ),
                'description' => esc_html__( 'We have well prepared documentation which includes overall instructions and recommendations that are required in this theme.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_about_section',
                'settings'    => 'site_documentation_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Documentation', 'the-styled-blog' ),
                        'url'   => esc_url( '//doc.blazethemes.com/the-styled-blog' )
                    )
                )
            ))
        );

        // theme documentation info box
        $wp_customize->add_setting( 'site_support_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_support_info', array(
                'label'	      => esc_html__( 'Theme Support', 'the-styled-blog' ),
                'description' => esc_html__( 'We provide 24/7 support regarding any theme issue. Our support team will help you to solve any kind of issue. Feel free to contact us.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_about_section',
                'settings'    => 'site_support_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Support Form', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/support' )
                    )
                )
            ))
        );

        // theme documentation info box
        $wp_customize->add_setting( 'site_review_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_review_info', array(
                'label'	      => esc_html__( 'Review Theme', 'the-styled-blog' ),
                'description' => esc_html__( 'we would like to hear from you. How was your experience using this theme?', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_about_section',
                'settings'    => 'site_review_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Add my review', 'the-styled-blog' ),
                        'url'   => esc_url( '//wordpress.org/support/theme/the-styled-blog/reviews/?filter=5' )
                    )
                )
            ))
        );

        // demo import info box
        $wp_customize->add_setting( 'demo_import_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'demo_import_info', array(
                'label'	      => esc_html__( 'One Click Demo Import', 'the-styled-blog' ),
                'description' => esc_html__( 'We provide one click easy demo import. With this you can make clone of our pre built demos.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_about_section',
                'settings'    => 'demo_import_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Demo import', 'the-styled-blog' ),
                        'url'   => esc_url( admin_url( '/themes.php?page=the-styled-blog-info.php' )  )
                    )
                )
            ))
        );

        // upgrade pro info box
        $wp_customize->add_setting( 'upgrade_pro_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'upgrade_pro_info', array(
                'label'	      => esc_html__( 'Premium Upgrade', 'the-styled-blog' ),
                'description' => esc_html__( 'Unlock advanced and many more features. We provide 1 year of free support for any kind of license purchase', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_about_section',
                'settings'    => 'upgrade_pro_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro/' )
                    )
                )
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_about_theme_panel', 10 );
endif;