<?php
/**
 * Blog Archive Panel
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
if( !function_exists( 'the_styled_blog_customizer_blog_archive_panel' ) ) :
    /**
     * Register blog archive section settings
     * 
     */
    function the_styled_blog_customizer_blog_archive_panel( $wp_customize ) {
        /**
         * Blog page / archive section
         * 
         * @since 1.0.0
         */
        $wp_customize->add_section( 'the_styled_blog_blog_archive_section', array(
            'title' => esc_html__( 'Blog page / Archive', 'the-styled-blog' ),
            'priority'  => 35
        ));

        /**
         * Pagination Type settings
         * 
         */
        $wp_customize->add_setting( 'archive_pagination_setting_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'archive_pagination_setting_header', array(
                'label'       => esc_html__( 'Pagination Type', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_pagination_setting_header',
                'type'        => 'section-heading'
            ))
        );

        /**
         * Archive pagination type type
         * 
         */
        $wp_customize->add_setting( 'archive_pagination_type', array(
            'default' => 'pagination',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'archive_pagination_type', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_blog_archive_section',
            'label'     => __( 'Pagination Type', 'the-styled-blog' ),
            'choices'   => array(
                'pagination' => esc_html__( 'Pagination', 'the-styled-blog' ),
                'ajax' => esc_html__( 'Ajax Load ( load posts without page load )', 'the-styled-blog' )
            ),
        ));

        /**
         * Related Posts Section Title
         * 
         */
        $wp_customize->add_setting( 'archive_ajax_button_label', array(
            'default'   => esc_html__( 'Load more', 'the-styled-blog' ),
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage'
        ));

        $wp_customize->add_control( 'archive_ajax_button_label', array(
            'label'    => esc_html__( 'Ajax Load Button Label', 'the-styled-blog' ),
            'section'  => 'the_styled_blog_blog_archive_section',		
            'type'     => 'text',
            'active_callback'   => function( $setting ) {
                if ( $setting->manager->get_setting( 'archive_pagination_type' )->value() === 'pagination' ) {
                    return false;
                }
                return true;
            }
        ));

        /**
         * Archive general content settings
         * 
         */
        $wp_customize->add_setting( 'archive_general_content_setting_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'archive_general_content_setting_header', array(
                'label'       => esc_html__( 'General Content', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_general_content_setting_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Archive content dropcap option
         *
         */
        $wp_customize->add_setting( 'archive_dropcap_option', array(
            'default'           => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'archive_dropcap_option', array(
                'label'       => esc_html__( 'Enable dropcap ( first letter appear bigger )', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_dropcap_option'
            ))
        );

        /**
         * Archive post content type
         * 
         */
        $wp_customize->add_setting( 'archive_content_type', array(
            'default' => 'excerpt',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'archive_content_type', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_blog_archive_section',
            'label'     => __( 'Post Content to display', 'the-styled-blog' ),
            'choices'   => array(
                'excerpt' => esc_html__( 'Excerpt', 'the-styled-blog' ),
                'content' => esc_html__( 'Content', 'the-styled-blog' ),
                'none' => esc_html__( 'None', 'the-styled-blog' )
            ),
        ));
        
        /**
         * Archive Posted on Date Option
         * 
         */
        $wp_customize->add_setting( 'archive_post_date_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'archive_post_date_option', array(
                'label'	      => esc_html__( 'Show/Hide post date', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_post_date_option'
            ))
        );

        /**
         * Archive Comments Number Option
         * 
         */
        $wp_customize->add_setting( 'archive_post_comments_num_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'archive_post_comments_num_option', array(
                'label'	      => esc_html__( 'Show/Hide post comments number', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_post_comments_num_option'
            ))
        );

        /**
         * Archive Category Option
         * 
         */
        $wp_customize->add_setting( 'archive_post_categories_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'archive_post_categories_option', array(
                'label'	      => esc_html__( 'Show/Hide post categories', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_post_categories_option'
            ))
        );

        /**
         * Archive Read more Option
         * 
         */
        $wp_customize->add_setting( 'archive_read_more_option', array(
            'default'         => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'archive_read_more_option', array(
                'label'	      => esc_html__( 'Show/Hide read more', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_read_more_option'
            ))
        );

        /**
         * Add read more text
         * 
         */
        $wp_customize->add_setting( 'archive_read_more_text', array(
            'default'        => esc_html__( 'Read more', 'the-styled-blog' ),
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control( 'archive_read_more_text', array(
            'label'    => esc_html__( 'Read more text', 'the-styled-blog' ),
            'section'  => 'the_styled_blog_blog_archive_section',		
            'type'     => 'text'
        ));

        /**
         * Redirect widgets link
         * 
         */
        $wp_customize->add_setting( 'archive_social_share_redirects', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Redirect_Control( $wp_customize, 'archive_social_share_redirects', array(
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_social_share_redirects',
                'choices'     => array(
                    'footer-column-one' => array(
                        'type'  => 'section',
                        'id'    => 'the_styled_blog_social_share_section',
                        'label' => esc_html__( 'Manage social share icons', 'the-styled-blog' )
                    )
                )
            ))
        );

        /**
         * Single Related Posts settings
         * 
         */
        $wp_customize->add_setting( 'archive_related_posts_setting_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'archive_related_posts_setting_header', array(
                'label'       => esc_html__( 'Related Posts', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_related_posts_setting_header'
            ))
        );

        /**
         * Single Related Posts Section Option
         * 
         */
        $wp_customize->add_setting( 'archive_post_related_posts_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'archive_post_related_posts_option', array(
                'label'	      => esc_html__( 'Show/Hide related posts', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_post_related_posts_option'
            ))
        );

        /**
         * Related Posts Section Title
         * 
         */
        $wp_customize->add_setting( 'archive_post_related_posts_title', array(
            'default'   => esc_html__( 'Related Posts', 'the-styled-blog' ),
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control( 'archive_post_related_posts_title', array(
            'label'    => esc_html__( 'Related posts title', 'the-styled-blog' ),
            'section'  => 'the_styled_blog_blog_archive_section',		
            'type'     => 'text'
        ));
        
        /**
         * Single Relate Posts Count
         * 
         */
        $wp_customize->add_setting( 'archive_post_related_posts_count', array(
            'default'        => 3,
            'sanitize_callback' => 'absint',
        ));

        $wp_customize->add_control( 'archive_post_related_posts_count', array(
            'label'    => esc_html__( 'Posts Count', 'the-styled-blog' ),
            'section'  => 'the_styled_blog_blog_archive_section',		
            'type'     => 'number',
            'input_attrs'   => array(
                'min'   => 1,
                'step'  => 1,
                'max'   => 3
            )
        ));

        /**
         * Archive show or hide on mobile and tablet option
         *
         */
        $wp_customize->add_setting( 'archive_post_related_posts_responsive_display', array(
            'default'           => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
            'transport' => 'postMessage'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'archive_post_related_posts_responsive_display', array(
                'label'       => esc_html__( 'Show section on mobile and tablet', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'archive_post_related_posts_responsive_display',
                'active_callback'   => function( $setting ) {
                    return $setting->manager->get_setting( 'archive_post_related_posts_option' )->value();
                }
            ))
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_archive_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_archive_info', array(
                'label'	      => esc_html__( 'For more layouts and settings', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_archive_section',
                'settings'    => 'site_archive_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_blog_archive_panel', 10 );
endif;