<?php
/**
 * Featured Links Panel
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
if( !function_exists( 'the_styled_blog_customizer_featured_links_panel' ) ) :
    /**
     * Register featured links section settings
     * 
     */
    function the_styled_blog_customizer_featured_links_panel( $wp_customize ) {
        /**
         * Featured Links section
         * 
         * @since 1.0.0
         */
        $wp_customize->add_section( 'the_styled_blog_featured_links_section', array(
            'title' => esc_html__( 'Featured Links', 'the-styled-blog' ),
            'priority'  => 30
        ));

        /**
         * Featured Links layout setting heading
         */
        $wp_customize->add_setting( 'featured_links_layout_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'featured_links_layout_settings_header', array(
                'label'	      => esc_html__( 'General Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_featured_links_section',
                'settings'    => 'featured_links_layout_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Featured Links option
         */
        $wp_customize->add_setting( 'featured_links_option', array(
            'default'   => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'featured_links_option', array(
                'label'	      => esc_html__( 'Show featured links', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_featured_links_section',
                'settings'    => 'featured_links_option'
            ))
        );

        /**
         * Featured Links display on
         * 
         */
        $wp_customize->add_setting( 'featured_links_display_on', array(
            'default' => 'front-blog',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'featured_links_display_on', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_featured_links_section',
            'label'     => esc_html__( 'Orderby', 'the-styled-blog' ),
            'choices'   => array(
                'front' => esc_html__( 'Frontpage', 'the-styled-blog' ),
                'blog'  => esc_html__( 'Posts page', 'the-styled-blog' ),
                'front-blog'    => esc_html__( 'Frontpage and posts page', 'the-styled-blog' )
            )
        ));

        /**
         * Featured Links content setting heading
         * 
         */
        $wp_customize->add_setting( 'featured_links_content_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field',
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'featured_links_content_settings_header', array(
                'label'	      => esc_html__( 'Content Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_featured_links_section',
                'settings'    => 'featured_links_content_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Section title
         * 
         */
        $wp_customize->add_setting( 'featured_links_title', array(
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control( 'featured_links_title', array(
            'label'    => esc_html__( 'Section Title', 'the-styled-blog' ),
            'section'  => 'the_styled_blog_featured_links_section',		
            'type'     => 'text'
        ));

        /**
         * Featured Links content type
         * 
         */
        $wp_customize->add_setting( 'featured_links_content_type', array(
            'default' => 'custom',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'featured_links_content_type', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_featured_links_section',
            'label'     => esc_html__( 'Content Type', 'the-styled-blog' ),
            'choices'   => array(
                'categories'=> esc_html__( 'Post Categories', 'the-styled-blog' ),
                'custom'    => esc_html__( 'Custom Links', 'the-styled-blog' )
            ),
        ));

        /**
         * Featured Links categories
         * 
         */
        $wp_customize->add_setting( 'featured_links_categories', array(
            'default' => '[]',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Multicheckbox_Control( $wp_customize, 'featured_links_categories', array(
                'label'     => esc_html__( 'Posts Categories', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_featured_links_section',
                'settings'  => 'featured_links_categories',
                'choices'   => the_styled_blog_get_multicheckbox_categories_array(),
                'active_callback'   => function( $setting ) {
                    if ( $setting->manager->get_setting( 'featured_links_content_type' )->value() === 'categories' ) {
                        return true;
                    }
                    return false;
                }
            ))
        );

        /**
         * Featured Links Items
         * 
         */
        $wp_customize->add_setting( 'featured_links_items', array(
            'default'   => json_encode(array(
                array(
                    'item_image'    => '',
                    'item_title'    => esc_html__( 'Featured Link', 'the-styled-blog' ),
                    'item_url'  => '',
                    'item_option'   => 'show'
                ),
                array(
                    'item_image'    => '',
                    'item_title'    => esc_html__( 'Featured Link 2', 'the-styled-blog' ),
                    'item_url'  => '',
                    'item_option'   => 'show'
                ),
                array(
                    'item_image'    => '',
                    'item_title'    => esc_html__( 'Featured Link 3', 'the-styled-blog' ),
                    'item_url'  => '',
                    'item_option'   => 'show'
                )
            )),
            'sanitize_callback' => 'the_styled_blog_sanitize_repeater_control'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Custom_Repeater( $wp_customize, 'featured_links_items', array(
                'label'         => esc_html__( 'Featured links', 'the-styled-blog' ),
                'description'   => esc_html__( 'Hold item and drag vertically to re-order the icons', 'the-styled-blog' ),
                'section'       => 'the_styled_blog_featured_links_section',
                'settings'      => 'featured_links_items',
                'row_label'     => esc_html__( 'Featured Item', 'the-styled-blog' ),
                'add_new_label' => esc_html__( 'Add new item', 'the-styled-blog' ),
                'fields'        => array(
                    'item_image'   => array(
                        'type'          => 'image',
                        'label'         => esc_html__( 'Image', 'the-styled-blog' ),
                        'description'   => esc_html__( 'Choose from the library or upload an image.', 'the-styled-blog' ),
                        'default'       => esc_attr( 'fab fa-instagram' )

                    ),
                    'item_title'  => array(
                        'type'      => 'text',
                        'label'     => esc_html__( 'Title', 'the-styled-blog' ),
                        'default'   => ''
                    ),
                    'item_url'  => array(
                        'type'      => 'url',
                        'label'     => esc_html__( 'URL for featured item', 'the-styled-blog' ),
                        'default'   => ''
                    ),
                    'item_option'             => 'show'
                ),
                'active_callback'   => function( $setting ) {
                    if ( $setting->manager->get_setting( 'featured_links_content_type' )->value() === 'custom' ) {
                        return true;
                    }
                    return false;
                }
            ))
        );

        /**
         * Featured Links title option
         * 
         */
        $wp_customize->add_setting( 'featured_links_title_option', array(
            'default'   => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'featured_links_title_option', array(
                'label' => esc_html__( 'Show links title', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_featured_links_section',
                'settings'  => 'featured_links_title_option',
                'type'      => 'simple-toggle-button'
            ))
        );

        /**
         * Categories count option
         * 
         */
        $wp_customize->add_setting( 'featured_links_categories_count_option', array(
            'default'   => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'featured_links_categories_count_option', array(
                'label' => esc_html__( 'Show categories count', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_featured_links_section',
                'settings'  => 'featured_links_categories_count_option',
                'type'      => 'simple-toggle-button',
                'active_callback'   => function( $setting ) {
                    if ( $setting->manager->get_setting( 'featured_links_content_type' )->value() === 'categories' ) {
                        return true;
                    }
                    return false;
                }
            ))
        );

        /**
         * Featured Links carousel setting heading
         */
        $wp_customize->add_setting( 'featured_links_carousel_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'featured_links_carousel_settings_header', array(
                'label'	      => esc_html__( 'Carousel Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_featured_links_section',
                'settings'    => 'featured_links_carousel_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Featured Links column option
         */
        $wp_customize->add_setting( 'featured_links_carousel_column', array(
            'default'   => 'three',
            'sanitize_callback' => 'sanitize_text_field'
        ) );
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Tab_Group_Control( $wp_customize, 'featured_links_carousel_column', array(
                'label'     => esc_html__( 'Column control', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_featured_links_section',
                'settings'  => 'featured_links_carousel_column',
                'choices'   => array(
                    'two'   => array(
                        'label' => esc_html__( 'Two', 'the-styled-blog' )
                    ),
                    'three' => array(
                        'label' => esc_html__( 'Three', 'the-styled-blog' )
                    )
                )
            ))
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_featured_links_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_featured_links_info', array(
                'label'	      => esc_html__( 'For more layouts and settings', 'the-styled-blog' ),
                'description' => esc_html__( '3 section layouts, carousel slider, 4 columns and more items available in pro.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_featured_links_section',
                'settings'    => 'site_featured_links_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_featured_links_panel', 10 );
endif;