<?php
/**
 * Global Options Section
 *
 */
if( !function_exists( 'the_styled_blog_customizer_global_options_section' ) ) :
    /**
     * Register global options settings
     *
     */
    function the_styled_blog_customizer_global_options_section( $wp_customize ) {
        /**
         * Miscellaneous
         * 
         * panel - misc_section
         */
        $wp_customize->add_section( 'misc_section', array(
            'title' => esc_html__( 'Miscs', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_global_options_panel',
            'priority'  => 5
        ));

        // Lazy load Option
        $wp_customize->add_setting( 'lazy_load_option', array(
            'default'           => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'lazy_load_option', array(
                'label'	      => esc_html__( 'Enable lazy load images', 'the-styled-blog' ),
                'description' => esc_html__( 'Helps to load your site faster. Enabling this option will use the wordpress default lazyload functionality. This will only load the images, videos and audios when its on windows viewport.', 'the-styled-blog' ),
                'section'     => 'misc_section',
                'settings'    => 'lazy_load_option'
            ))
        );

        /**
         * Sticky header section
         *
         * panel - the_styled_blog_global_options_panel
         */
        $wp_customize->add_section( 'the_styled_blog_global_sticky_header_section', array(
          'title' => esc_html__( 'Sticky Header', 'the-styled-blog' ),
          'panel' => 'the_styled_blog_global_options_panel',
          'priority'  => 5,
        ));

        /**
         * Sticky header Option
         *
         */
        $wp_customize->add_setting( 'sticky_header_option', array(
          'default'         => false,
          'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'sticky_header_option', array(
                'label'	      => esc_html__( 'Enable sticky header', 'the-styled-blog' ),
                'description' => esc_html__( 'Header section will be fixed through out the whole website.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_global_sticky_header_section',
                'settings'    => 'sticky_header_option'
            ))
        );

        /**
         * Scroll to top show or hide on mobile and tablet option
         *
         */
        $wp_customize->add_setting( 'sticky_header_responsive_display', array(
            'default'           => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
            'transport' => 'postMessage'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'sticky_header_responsive_display', array(
                'label'       => esc_html__( 'Enable sticky on mobile and tablet', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_global_sticky_header_section',
                'settings'    => 'sticky_header_responsive_display',
                'active_callback'   => function( $setting ) {
                    return $setting->manager->get_setting( 'sticky_header_option' )->value();
                }
            ))
        );

        /**
         * Social Section
         *
         * panel - the_styled_blog_global_options_panel
         */
        $wp_customize->add_section( 'the_styled_blog_social_section', array(
            'title' => esc_html__( 'Social', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_global_options_panel',
            'priority'  => 10,
        ));

        /**
         * Global Social Setting Heading
         *
         */
        $wp_customize->add_setting( 'global_social_settings_header', array(
          'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'global_social_settings_header', array(
                'label'	      => esc_html__( 'Social Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_section',
                'settings'    => 'global_social_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Social icons target attribute value
         * 
         */
        $wp_customize->add_setting( 'social_icons_target', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_select',
            'default'   => '_blank',
            'transport' => 'postMessage'
        ));
        
        $wp_customize->add_control( 'social_icons_target', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_social_section',
            'label'     => esc_html__( 'Social Icon Link Open in', 'the-styled-blog' ),
            'description' => esc_html__( 'Sets the target attribute according to the value.', 'the-styled-blog' ),
            'choices'   => array(
                '_blank' => __( 'Open link in new tab', 'the-styled-blog' ),
                '_self'  => __( 'Open link in same tab', 'the-styled-blog' )
            )
        ));

        // social icons repeater field
        $wp_customize->add_setting( 'social_icons', array(
            'default'   => json_encode( array(
                array(
                    'icon_class'    => esc_attr( 'fab fa-linkedin-in' ),
                    'icon_url'  => '',
                    'item_option'   => 'show'
                ),
                array(
                    'icon_class'    => esc_attr( 'fab fa-twitter' ),
                    'icon_url'  => '',
                    'item_option'   => 'show'
                ),
                array(
                    'icon_class'    => esc_attr( 'fab fa-vimeo-v' ),
                    'icon_url'  => '',
                    'item_option'   => 'show'
                ),
                array(
                    'icon_class'    => esc_attr( 'fab fa-instagram' ),
                    'icon_url'  => '',
                    'item_option'   => 'show'
                )
            )),
            'sanitize_callback' => 'the_styled_blog_sanitize_repeater_control'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Custom_Repeater( $wp_customize, 'social_icons', array(
                'label'         => esc_html__( 'Social Icons', 'the-styled-blog' ),
                'description'   => esc_html__( 'Hold item and drag  vertically to re-order the icons', 'the-styled-blog' ),
                'section'       => 'the_styled_blog_social_section',
                'settings'      => 'social_icons',
                'row_label'     => esc_html__( 'Social icon', 'the-styled-blog' ),
                'add_new_label' => esc_html__( 'Add new icon', 'the-styled-blog' ),
                'fields'        => array(
                    'icon_class'   => array(
                        'type'          => 'fontawesome-icon-picker',
                        'label'         => esc_html__( 'Social icon', 'the-styled-blog' ),
                        'description'   => esc_html__( 'Select from dropdown', 'the-styled-blog' )
                    ),
                    'icon_url'  => array(
                        'type'          => 'url',
                        'label'         => esc_html__( 'URL for icon', 'the-styled-blog' ),
                    ),
                    'item_option'             => 'show'
                ),
            ))
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_social_upgrade_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_social_upgrade_info', array(
                'label'	      => esc_html__( 'For more social icons', 'the-styled-blog' ),
                'description' => esc_html__( 'You can add unlimited social icons in pro.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_section',
                'settings'    => 'site_social_upgrade_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );

        /**
         * Social Share Section
         *
         * panel - the_styled_blog_global_options_panel
         */
        $wp_customize->add_section( 'the_styled_blog_social_share_section', array(
            'title' => esc_html__( 'Social Share', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_global_options_panel',
            'priority'  => 15,
        ));

        /**
         * Global Social Setting Heading
         *
         */
        $wp_customize->add_setting( 'global_social_share_settings_header', array(
          'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'global_social_share_settings_header', array(
                'label'	      => esc_html__( 'Social Share Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'global_social_share_settings_header',
                'type'        => 'section-heading',
            ))
        );

        // Social share twitter option
        $wp_customize->add_setting( 'social_share_twitter_option', array(
            'default'           => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'social_share_twitter_option', array(
                'label'       => esc_html__( 'Show twitter share', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'social_share_twitter_option'
            ))
        );

        // Social share facebook option
        $wp_customize->add_setting( 'social_share_facebook_option', array(
            'default'           => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'social_share_facebook_option', array(
                'label'       => esc_html__( 'Show facebook share', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'social_share_facebook_option'
            ))
        );

        // Social share pinterest option
        $wp_customize->add_setting( 'social_share_pinterest_option', array(
            'default'           => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'social_share_pinterest_option', array(
                'label'       => esc_html__( 'Show pinterest share', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'social_share_pinterest_option'
            ))
        );

        // Social share linkedin option
        $wp_customize->add_setting( 'social_share_linkedin_option', array(
            'default'           => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'social_share_linkedin_option', array(
                'label'       => esc_html__( 'Show linkedin share', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'social_share_linkedin_option'
            ))
        );

        /**
         * Archive Social Share Setting Heading
         *
         */
        $wp_customize->add_setting( 'archive_social_share_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'archive_social_share_settings_header', array(
                'label'	      => esc_html__( 'Blog / Archive Page', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'archive_social_share_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Archive social share option
         *
         */
        $wp_customize->add_setting( 'archive_social_share_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'archive_social_share_option', array(
                'label'	      => esc_html__( 'Show social share on archive', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'archive_social_share_option'
            ))
        );

        // Archive social share position
        $wp_customize->add_setting( 'archive_social_share_position', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_select',
            'default'   => 'after_content',
        ));
        
        $wp_customize->add_control( 'archive_social_share_position', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_social_share_section',
            'label'     => esc_html__( 'Display social share html on', 'the-styled-blog' ),
            'choices'   => array(
                'before_content' => __( 'Before Content', 'the-styled-blog' ),
                'after_content'  => __( 'After Content', 'the-styled-blog' )
            )
        ));

        /**
         * Post Social Share Setting Heading
         *
         */
        $wp_customize->add_setting( 'single_social_share_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'single_social_share_settings_header', array(
                'label'	      => esc_html__( 'Single Post Page', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'single_social_share_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Single social share option
         *
         */
        $wp_customize->add_setting( 'single_social_share_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'single_social_share_option', array(
                'label'	      => esc_html__( 'Show social share on single', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_social_share_section',
                'settings'    => 'single_social_share_option'
            ))
        );

        // Single social share position
        $wp_customize->add_setting( 'single_social_share_position', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_select',
            'default'   => 'after_content',
        ));
        
        $wp_customize->add_control( 'single_social_share_position', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_social_share_section',
            'label'     => esc_html__( 'Display social share html on', 'the-styled-blog' ),
            'choices'   => array(
                'before_content' => __( 'Before Content', 'the-styled-blog' ),
                'after_content'  => __( 'After Content', 'the-styled-blog' )
            )
        ));

        /**
         * Global Container Section
         *
         * panel - the_styled_blog_global_options_panel
         */
        $wp_customize->add_section( 'the_styled_blog_global_container_section', array(
          'title' => esc_html__( 'Container', 'the-styled-blog' ),
          'panel' => 'the_styled_blog_global_options_panel',
          'priority'  => 30
        ));

        /**
         * Scroll To Top Style Setting Heading
         *
         */
        $wp_customize->add_setting( 'global_sttop_style_settings_header', array(
          'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'global_sttop_style_settings_header', array(
                'label'	      => esc_html__( 'Style ', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_scroll_top_section',
                'settings'    => 'global_sttop_style_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Container Width Setting
         *
         */
        $wp_customize->add_setting( 'the_styled_blog_global_container_width', array(
          'sanitize_callback' => 'the_styled_blog_sanitize_number_range',
          'default'           => 1126
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Range_Control( $wp_customize, 'the_styled_blog_global_container_width', array(
                'label'	      => esc_html__( 'Container width (px)', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_global_container_section',
                'settings'    => 'the_styled_blog_global_container_width',
                'unit'        => 'px',
                'input_attrs' => array(
                  'max'         => 1900,
                  'min'         => 780,
                  'step'        => 1,
                  'reset' => true
                )
            ))
        );

        /**
         * Sidebar Width Setting
         *
         */
        $wp_customize->add_setting( 'the_styled_blog_global_container_sidebar_width', array(
          'sanitize_callback' => 'the_styled_blog_sanitize_number_range',
          'default'           => 25
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Range_Control( $wp_customize, 'the_styled_blog_global_container_sidebar_width', array(
                'label'	      => esc_html__( 'Sidebar width (%)', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_global_container_section',
                'settings'    => 'the_styled_blog_global_container_sidebar_width',
                'unit'        => '%',
                'input_attrs' => array(
                  'max'         => 50,
                  'min'         => 20,
                  'step'        => 1,
                  'reset' => true
                )
            ))
        );
        
        /**
         * Sticky sidebar Section
         *
         * panel - the_styled_blog_global_options_panel
         */
        $wp_customize->add_section( 'the_styled_blog_global_sticky_sidebar_section', array(
            'title' => esc_html__( 'Sticky Sidebar', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_global_options_panel',
            'priority'  => 100,
        ));

        /**
         * Sticky sidebar Option
         *
         */
        $wp_customize->add_setting( 'sticky_sidebars_option', array(
            'default'         => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'sticky_sidebars_option', array(
                'label'	      => esc_html__( 'Enable sticky sidebars', 'the-styled-blog' ),
                'description' => esc_html__( 'This will avoid users to see blank space when the length of content is longer than sidebars. This functionality is disabled in responsive devices as the sidebar appears below the content.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_global_sticky_sidebar_section',
                'settings'    => 'sticky_sidebars_option'
            ))
        );

        /**
         * Scroll To Top Section
         *
         * panel - the_styled_blog_global_options_panel
         */
        $wp_customize->add_section( 'the_styled_blog_scroll_top_section', array(
            'title' => esc_html__( 'Scroll To Top', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_global_options_panel',
            'priority'  => 100,
        ));

        /**
         * Scroll To Top Content Setting Heading
         *
         */
        $wp_customize->add_setting( 'global_sttop_content_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'global_sttop_content_settings_header', array(
                'label'	      => esc_html__( 'Content ', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_scroll_top_section',
                'settings'    => 'global_sttop_content_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Scroll To Top Option
         *
         */
        $wp_customize->add_setting( 'scroll_to_top_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'scroll_to_top_option', array(
                'label'	      => esc_html__( 'Show scroll to top', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_scroll_top_section',
                'settings'    => 'scroll_to_top_option'
            ))
        );

        /**
         * Scroll to top show or hide on mobile and tablet option
         *
         */
        $wp_customize->add_setting( 'scroll_to_top_responsive_display', array(
            'default'           => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
            'transport' => 'postMessage'
        ));

        $wp_customize->add_control(
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'scroll_to_top_responsive_display', array(
                'label'       => esc_html__( 'Show button on mobile and tablet', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_scroll_top_section',
                'settings'    => 'scroll_to_top_responsive_display',
                'active_callback'   => function( $setting ) {
                    return $setting->manager->get_setting( 'scroll_to_top_option' )->value();
                }
            ))
        );

        /**
         * Scroll To Top Align
         *
         */
        $wp_customize->add_setting( 'scroll_to_top_align',
            array(
            'default'           => 'align--right',
            'sanitize_callback' => 'sanitize_text_field',
            )
        );

        // Add the layout control.
        $wp_customize->add_control( new The_Styled_Blog_WP_Tab_Group_Control(
            $wp_customize,
            'scroll_to_top_align',
                array(
                'label'    => esc_html__( 'Button Align', 'the-styled-blog' ),
                'section'  => 'the_styled_blog_scroll_top_section',
                'choices'  => array(
                    'align--left' => array(
                        'label'  => esc_html__( 'Left', 'the-styled-blog' )
                    ),
                    'align--center' => array(
                        'label'  => esc_html__( 'Center', 'the-styled-blog' )
                    ),
                    'align--right' => array(
                        'label'  => esc_html__( 'Right', 'the-styled-blog' )
                    )
                )
            )
        ));

        /**
         * Scroll To Top Style Setting Heading
         *
         */
        $wp_customize->add_setting( 'global_sttop_style_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'global_sttop_style_settings_header', array(
                'label'	      => esc_html__( 'Style ', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_scroll_top_section',
                'settings'    => 'global_sttop_style_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Scroll to top padding settings
         * 
         */
        $wp_customize->add_setting( 'scroll_to_top_padding', array( 
            'default' => array( 'desktop'   => array( 'top'=>'10px', 'right'	=> '10px', 'bottom'	=> '10px', 'left'	=> '10px' ), 'tablet'   => array( 'top'=>'10px', 'right'	=> '10px', 'bottom'	=> '10px', 'left'	=> '10px' ), 'smartphone'   => array( 'top'=>'5px', 'right'	=> '5px', 'bottom'	=> '5px', 'left'	=> '5px' ) ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Responsive_Box_Control( $wp_customize, 'scroll_to_top_padding', array(
                'label'       => esc_html__( 'Padding', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_scroll_top_section',
                'settings'    => 'scroll_to_top_padding'
            ))
        );

        // scroll to top border settings
        $wp_customize->add_setting( 'scroll_to_top_border', array(
            'default'   => array( 'type'=> 'solid', 'color'=> '#000000', 'width'=> 1, 'radius'=> 0 ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Border_Box_Control( $wp_customize, 'scroll_to_top_border', array(
                'label'     => esc_html__( 'Border', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_scroll_top_section',
                'settings'  => 'scroll_to_top_border',
            ))
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_scroll_to_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_scroll_to_info', array(
                'label'	      => esc_html__( 'For more settings', 'the-styled-blog' ),
                'description' => esc_html__( 'Colors, background colors and hover colors.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_scroll_top_section',
                'settings'    => 'site_scroll_to_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
  }
  add_action( 'customize_register', 'the_styled_blog_customizer_global_options_section', 10 );
endif;