<?php
/**
 * Main Banner Panel
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
if( !function_exists( 'the_styled_blog_customizer_main_banner_panel' ) ) :
    /**
     * Register main banner section settings
     * 
     */
    function the_styled_blog_customizer_main_banner_panel( $wp_customize ) {
        /**
         * Main Banner section
         * 
         */
        $wp_customize->add_section( 'the_styled_blog_main_banner_section', array(
            'title' => esc_html__( 'Main Banner', 'the-styled-blog' ),
            'priority'  => 30
        ));

        /**
         * Main banner content setting heading
         * 
         */
        $wp_customize->add_setting( 'main_banner_layout_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'main_banner_layout_settings_header', array(
                'label'	      => esc_html__( 'Content Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_layout_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Main Banner option
         * 
         */
        $wp_customize->add_setting( 'main_banner_option', array(
            'default'   => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'main_banner_option', array(
                'label'	      => esc_html__( 'Show main banner', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_option'
            ))
        );

        /**
         * Main Banner slider display on
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_display_on', array(
            'default' => 'front-blog',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'main_banner_slider_display_on', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_main_banner_section',
            'label'     => esc_html__( 'Orderby', 'the-styled-blog' ),
            'choices'   => array(
                'front' => esc_html__( 'Frontpage', 'the-styled-blog' ),
                'blog'  => esc_html__( 'Posts page', 'the-styled-blog' ),
                'front-blog'    => esc_html__( 'Frontpage and posts page', 'the-styled-blog' )
            )
        ));

        /**
         * Main banner slider setting heading
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'main_banner_slider_settings_header', array(
                'label'	      => esc_html__( 'Slider Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_slider_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Main Banner slider orderby
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_order_by', array(
            'default' => 'date-desc',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'main_banner_slider_order_by', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_main_banner_section',
            'label'     => esc_html__( 'Orderby', 'the-styled-blog' ),
            'choices'   => array(
                'date-desc' => esc_html__( 'Newest - Oldest', 'the-styled-blog' ),
                'date-asc' => esc_html__( 'Oldest - Newest', 'the-styled-blog' ),
                'title-asc' => esc_html__( 'A - Z', 'the-styled-blog' ),
                'title-desc' => esc_html__( 'Z - A', 'the-styled-blog' )
            ),
        ));

        /**
         * Main Banner slider categories
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_categories', array(
            'default' => '[]',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Multicheckbox_Control( $wp_customize, 'main_banner_slider_categories', array(
                'label'     => esc_html__( 'Posts Categories', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_main_banner_section',
                'settings'  => 'main_banner_slider_categories',
                'choices'   => the_styled_blog_get_multicheckbox_categories_array()
            ))
        );

        /**
         * Main Banner slider number of posts
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_numbers', array(
            'default' => 3,
            'sanitize_callback' => 'absint'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Range_Control( $wp_customize, 'main_banner_slider_numbers', array(
                'label'	      => esc_html__( 'Number of posts to display', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_slider_numbers',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 4,
                    'step'  => 1,
                    'reset' => true
                )
            ))
        );

        /**
         * Main Banner no thumb post option
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_post_no_thumb_hide_option', array(
            'default'   => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'main_banner_slider_post_no_thumb_hide_option', array(
                'label' => esc_html__( 'Hide post with no featured image', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_main_banner_section',
                'settings'  => 'main_banner_slider_post_no_thumb_hide_option'
            ))
        );

        /**
         * Main Banner slider post title option
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_post_title_option', array(
            'default'   => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'main_banner_slider_post_title_option', array(
                'label' => esc_html__( 'Show post title', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_main_banner_section',
                'settings'  => 'main_banner_slider_post_title_option'
            ))
        );

        /**
         * Main Banner slider categories option
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_categories_option', array(
            'default'   => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'main_banner_slider_categories_option', array(
                'label' => esc_html__( 'Show post categories', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_main_banner_section',
                'settings'  => 'main_banner_slider_categories_option'
            ))
        );

        /**
         * Main Banner slider date option
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_date_option', array(
            'default'   => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'main_banner_slider_date_option', array(
                'label'	      => esc_html__( 'Show post published date', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_slider_date_option'
            ))
        );

        /**
         * Main Banner slider comments option
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_comments_option', array(
            'default'   => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control'
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'main_banner_slider_comments_option', array(
                'label' => esc_html__( 'Show comments number', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_main_banner_section',
                'settings'  => 'main_banner_slider_comments_option'
            ))
        );

        /**
         * Main banner slider attributes setting heading
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_attr_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'main_banner_slider_attr_settings_header', array(
                'label'	      => esc_html__( 'Slider Attributes', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_slider_attr_settings_header',
                'type'        => 'section-heading',
            ))
        );
        
        /**
         * Main Banner slider fade option
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_fade', array(
            'default' => true,
            'sanitize_callback' => 'rest_sanitize_boolean'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'main_banner_slider_fade', array(
                'label'	      => esc_html__( 'Enable fade animation', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_slider_fade'
            ))
        );

        /**
         * Main Banner slider speed
         * 
         */
        $wp_customize->add_setting( 'main_banner_slider_speed', array(
            'default' => 300,
            'sanitize_callback' => 'absint'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Range_Control( $wp_customize, 'main_banner_slider_speed', array(
                'label'	      => esc_html__( 'Slider speed', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'main_banner_slider_speed',
                'input_attrs' => array(
                    'min'   => 200,
                    'max'   => 10000,
                    'step'  => 100,
                    'reset' => true
                )
            ))
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_banner_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_banner_info', array(
                'label'	      => esc_html__( 'For more layouts and settings', 'the-styled-blog' ),
                'description' => esc_html__( '4 banner layouts, slider settings and more banner items available in pro.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_main_banner_section',
                'settings'    => 'site_banner_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_main_banner_panel', 10 );
endif;