<?php
/**
 * Single Post Panel
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
if( !function_exists( 'the_styled_blog_customizer_single_post_panel' ) ) :
    /**
     * Register single post section settings
     * 
     */
    function the_styled_blog_customizer_single_post_panel( $wp_customize ) {
        /**
         * Single Post section
         * 
         * @since 1.0.0
         */
        $wp_customize->add_section( 'the_styled_blog_blog_single_post_section', array(
            'title' => esc_html__( 'Single post', 'the-styled-blog' ),
            'priority'  => 50
        ));

        /**
         * Single general content settings
         * 
         */
        $wp_customize->add_setting( 'single_general_content_setting_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'single_general_content_setting_header', array(
                'label'       => esc_html__( 'General Content', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_general_content_setting_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Single Posted on Date Option
         * 
         */
        $wp_customize->add_setting( 'single_post_date_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'single_post_date_option', array(
                'label'	      => esc_html__( 'Show/Hide post date', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_post_date_option'
            ))
        );
        
        /**
         * Single Category Option
         * 
         */
        $wp_customize->add_setting( 'single_post_categories_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'single_post_categories_option', array(
                'label'	      => esc_html__( 'Show/Hide post categories', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_post_categories_option'
            ))
        );

        /**
         * Single Comments Number Option
         * 
         */
        $wp_customize->add_setting( 'single_post_comments_num_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'single_post_comments_num_option', array(
                'label'	      => esc_html__( 'Show/Hide post comments number', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_post_comments_num_option'
            ))
        );

        /**
         * Single Tag Option
         * 
         */
        $wp_customize->add_setting( 'single_post_tags_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Checkbox_Control( $wp_customize, 'single_post_tags_option', array(
                'label'	      => esc_html__( 'Show/Hide post tags', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_post_tags_option'
            ))
        );

        /**
         * Redirect widgets link
         * 
         */
        $wp_customize->add_setting( 'single_social_share_redirects', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Redirect_Control( $wp_customize, 'single_social_share_redirects', array(
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_social_share_redirects',
                'choices'     => array(
                    'footer-column-one' => array(
                        'type'  => 'section',
                        'id'    => 'the_styled_blog_social_share_section',
                        'label' => esc_html__( 'Manage social share icons', 'the-styled-blog' )
                    )
                )
            ))
        );

        /**
         * Single Author Box settings
         * 
         */
        $wp_customize->add_setting( 'single_author_box_setting_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'single_author_box_setting_header', array(
                'label'       => esc_html__( 'Author Box', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_author_box_setting_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Single Author Box Option
         * 
         */
        $wp_customize->add_setting( 'single_post_author_box_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'single_post_author_box_option', array(
                'label'	      => esc_html__( 'Show/Hide author box', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_post_author_box_option'
            ))
        );

        /**
         * Single Related Posts settings
         * 
         */
        $wp_customize->add_setting( 'single_related_posts_setting_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'single_related_posts_setting_header', array(
                'label'       => esc_html__( 'Related Posts', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_related_posts_setting_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Single Related Posts Section Option
         * 
         */
        $wp_customize->add_setting( 'single_post_related_posts_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'single_post_related_posts_option', array(
                'label'	      => esc_html__( 'Show/Hide related posts', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'single_post_related_posts_option'
            ))
        );

        /**
         * Related Posts Section Title
         * 
         */
        $wp_customize->add_setting( 'single_post_related_posts_title', array(
            'default'   => esc_html__( 'Related Posts', 'the-styled-blog' ),
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control( 'single_post_related_posts_title', array(
            'label'    => esc_html__( 'Related posts title', 'the-styled-blog' ),
            'section'  => 'the_styled_blog_blog_single_post_section',		
            'type'     => 'text'
        ));
        
        /**
         * Single Related Posts Count
         * 
         */
        $wp_customize->add_setting( 'single_post_related_posts_count', array(
            'default'        => 3,
            'sanitize_callback' => 'absint',
        ));

        $wp_customize->add_control( 'single_post_related_posts_count', array(
            'label'    => esc_html__( 'Posts Count', 'the-styled-blog' ),
            'section'  => 'the_styled_blog_blog_single_post_section',		
            'type'     => 'number',
            'input_attrs'   => array(
                'min'   => 1,
                'step'  => 1,
                'max'   => 3
            )
        ));

        // upgrade info box
        $wp_customize->add_setting( 'site_single_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_single_info', array(
                'label'	      => esc_html__( 'For more layouts and settings', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_blog_single_post_section',
                'settings'    => 'site_single_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_single_post_panel', 10 );
endif;