<?php
/**
 * Footer Options Section
 * 
 */
if( !function_exists( 'the_styled_blog_customizer_footer_options_section' ) ) :
    /**
     * Register footer options settings
     * 
     */
    function the_styled_blog_customizer_footer_options_section( $wp_customize ) {
        /**
         * Content Section
         * 
         * panel - the_styled_blog_footer_panel
         */
        $wp_customize->add_section( 'the_styled_blog_footer_content_section', array(
            'title' => esc_html__( 'Content', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_footer_panel',
            'priority'  => 10,
        ));
        
        /**
         * General Social Setting Heading
         * 
         */
        $wp_customize->add_setting( 'footer_general_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'footer_general_settings_header', array(
                'label'	      => esc_html__( 'General Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_footer_content_section',
                'settings'    => 'footer_general_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Footer Option
         * 
         */
        $wp_customize->add_setting( 'footer_option', array(
            'default'   => false,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'footer_option', array(
                'label'	      => esc_html__( 'Enable footer section', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_footer_content_section',
                'settings'    => 'footer_option'
            ))
        );

        /**
         * Footer Widgets Redirect  Heading
         * 
         */
        $wp_customize->add_setting( 'footer_widgets_redirect_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'footer_widgets_redirect_settings_header', array(
                'label'	      => esc_html__( 'Footer Widgets', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_footer_content_section',
                'settings'    => 'footer_widgets_redirect_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Redirect widgets link
         * 
         */
        $wp_customize->add_setting( 'footer_widgets_redirects', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Redirect_Control( $wp_customize, 'footer_widgets_redirects', array(
                'label'	      => esc_html__( 'Widgets', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_footer_content_section',
                'settings'    => 'footer_widgets_redirects',
                'choices'     => array(
                    'footer-column-one' => array(
                        'type'  => 'section',
                        'id'    => 'sidebar-widgets-footer-column',
                        'label' => esc_html__( 'Manage footer widget one', 'the-styled-blog' )
                    ),
                    'footer-column-two' => array(
                        'type'  => 'section',
                        'id'    => 'sidebar-widgets-footer-column-2',
                        'label' => esc_html__( 'Manage footer widget two', 'the-styled-blog' )
                    ),
                    'footer-column-three' => array(
                        'type'  => 'section',
                        'id'    => 'sidebar-widgets-footer-column-3',
                        'label' => esc_html__( 'Manage footer widget three', 'the-styled-blog' )
                    ),
                    'footer-column-four' => array(
                        'type'  => 'section',
                        'id'    => 'sidebar-widgets-footer-column-4',
                        'label' => esc_html__( 'Manage footer widget four', 'the-styled-blog' )
                    )
                )
            ))
        );

        /**
         * Style Section
         * 
         * panel - the_styled_blog_theme_panel
         */
        $wp_customize->add_section( 'the_styled_blog_footer_style_section', array(
            'title' => esc_html__( 'Style', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_footer_panel',
            'priority'  => 20,
        ));

        /**
         * Footer Layouts Heading
         * 
         */
        $wp_customize->add_setting( 'footer_layout_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'footer_layout_settings_header', array(
                'label'	      => esc_html__( 'Footer Layouts', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_footer_style_section',
                'settings'    => 'footer_layout_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Footer Section width
         * 
         */
        $wp_customize->add_setting( 'footer_section_width', array(
            'default' => 'full-width',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'footer_section_width', array(
            'label' => esc_html__( 'Footer Width', 'the-styled-blog' ),
            'type' => 'select',
            'section' => 'the_styled_blog_footer_style_section',
            'choices' => array(
                'full-width' => __( 'Full Width', 'the-styled-blog' ),
                'boxed-width' => __( 'Boxed Width', 'the-styled-blog' )
            ),
        ));

        /**
         * Footer Widget column
         * 
         */
        $wp_customize->add_setting( 'footer_widget_column',
            array(
            'default'           => 'column-two',
            'sanitize_callback' => 'sanitize_text_field',
            )
        );

        // Add the layout control.
        $wp_customize->add_control( new The_Styled_Blog_WP_Radio_Image_Control(
            $wp_customize,
            'footer_widget_column',
            array(
                'section'  => 'the_styled_blog_footer_style_section',
                'choices'  => array(
                    'column-one' => array(
                        'label' => esc_html__( 'Column One', 'the-styled-blog' ),
                        'url'   => '%s/assets/images/customizer/footer-column-one.jpg'
                    ),
                    'column-two' => array(
                        'label' => esc_html__( 'Column Two', 'the-styled-blog' ),
                        'url'   => '%s/assets/images/customizer/footer-column-two.jpg'
                    ),
                    'column-three' => array(
                        'label' => esc_html__( 'Column Three', 'the-styled-blog' ),
                        'url'   => '%s/assets/images/customizer/footer-column-three.jpg'
                    ),
                    'column-four' => array(
                        'label' => esc_html__( 'Column Four', 'the-styled-blog' ),
                        'url'   => '%s/assets/images/customizer/footer-column-four.jpg'
                    )
                )
            )
        ));

        // upgrade info box
        $wp_customize->add_setting( 'site_footer_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_footer_info', array(
                'label'	      => esc_html__( 'For more settings', 'the-styled-blog' ),
                'description' => esc_html__( 'Text color and background colors.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_footer_style_section',
                'settings'    => 'site_footer_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );

        /**
         * Bottom Footer Section
         * 
         * panel - the_styled_blog_footer_panel
         */
        $wp_customize->add_section( 'the_styled_blog_bottom_footer_content_section', array(
            'title' => esc_html__( 'Bottom Footer', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_footer_panel',
            'priority'  => 50,
        ));

        /**
         * General Bottom Footer Setting Heading
         * 
         */
        $wp_customize->add_setting( 'bottom_footer_general_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'bottom_footer_general_settings_header', array(
                'label'	      => esc_html__( 'Content Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_bottom_footer_content_section',
                'settings'    => 'bottom_footer_general_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Bottom Footer Option
         * 
         */
        $wp_customize->add_setting( 'bottom_footer_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'bottom_footer_option', array(
                'label'	      => esc_html__( 'Enable bottom footer', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_bottom_footer_content_section',
                'settings'    => 'bottom_footer_option'
            ))
        );

        /**
         * Bottom footer site info
         * 
         */
        $wp_customize->add_setting( 'bottom_footer_site_info', array(
            'default'    => esc_html__( 'The Styled Blog - Modern WordPress Theme. %year% ', 'the-styled-blog' ),
            'sanitize_callback' => 'wp_kses_post'
        ));
        $wp_customize->add_control( 'bottom_footer_site_info', array(
                'label' => esc_html__( 'Copyright Text', 'the-styled-blog' ),
                'description' => esc_html__( 'Add %year% to retrieve current year.', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_bottom_footer_content_section',
                'type'  => 'textarea'
            )
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_bottom_footer_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_bottom_footer_info', array(
                'label'	      => esc_html__( 'For more settings', 'the-styled-blog' ),
                'description' => esc_html__( 'Text color and background colors.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_bottom_footer_content_section',
                'settings'    => 'site_bottom_footer_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_footer_options_section', 10 );
endif;