<?php
/**
 * Header Options Section
 * 
 */
if( !function_exists( 'the_styled_blog_customizer_header_options_section' ) ) :
    /**
     * Register header options settings
     * 
     */
    function the_styled_blog_customizer_header_options_section( $wp_customize ) {
        /**
         * Content Section
         * 
         * panel - the_styled_blog_header_panel
         */
        $wp_customize->add_section( 'the_styled_blog_header_content_section', array(
            'title' => esc_html__( 'Content', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_header_panel',
            'priority'  => 10,
        ));

        /**
         * Header Search Setting Heading
         * 
         */
        $wp_customize->add_setting( 'header_search_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'header_search_settings_header', array(
                'label'	      => esc_html__( 'Search Bar', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_content_section',
                'settings'    => 'header_search_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Search Option
         * 
         */
        $wp_customize->add_setting( 'header_search_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'header_search_option', array(
                'label'	      => esc_html__( 'Show search bar', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_content_section',
                'settings'    => 'header_search_option'
            ))
        );

        // header search color and hover color
        $wp_customize->add_setting( 'header_search_toggle_color_group', array(
            'default'   => array( 'color'   => null, 'hover'   => null ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Color_Group_Picker_Control( $wp_customize, 'header_search_toggle_color_group', array(
                'label'     => esc_html__( 'Color / Hover Color', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_header_content_section',
                'settings'  => 'header_search_toggle_color_group',
            ))
        );

        /**
         * Header social setting heading
         * 
         */
        $wp_customize->add_setting( 'header_social_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'header_social_settings_header', array(
                'label'	      => esc_html__( 'Social icons', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_content_section',
                'settings'    => 'header_social_settings_header',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Header Social Icons Option
         * 
         */
        $wp_customize->add_setting( 'header_social_option', array(
            'default'         => true,
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Toggle_Control( $wp_customize, 'header_social_option', array(
                'label'	      => esc_html__( 'Show social icons', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_content_section',
                'settings'    => 'header_social_option'
            ))
        );

        /**
         * Redirect widgets link
         * 
         */
        $wp_customize->add_setting( 'header_social_icons_redirects', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_toggle_control',
        ));
    
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Redirect_Control( $wp_customize, 'header_social_icons_redirects', array(
                'section'     => 'the_styled_blog_header_content_section',
                'settings'    => 'header_social_icons_redirects',
                'choices'     => array(
                    'footer-column-one' => array(
                        'type'  => 'section',
                        'id'    => 'the_styled_blog_social_section',
                        'label' => esc_html__( 'Manage social icons', 'the-styled-blog' )
                    )
                )
            ))
        );

        // header social icons color and hover color
        $wp_customize->add_setting( 'header_social_color_group', array(
            'default'   => array( 'color'   => null, 'hover'   => null ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array',
            'transport' => 'postMessage'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Color_Group_Picker_Control( $wp_customize, 'header_social_color_group', array(
                'label'     => esc_html__( 'Color / Hover Color', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_header_content_section',
                'settings'  => 'header_social_color_group',
            ))
        );

        /**
         * Style Section
         * 
         * panel - the_styled_blog_theme_panel
         */
        $wp_customize->add_section( 'the_styled_blog_header_style_section', array(
            'title' => esc_html__( 'Style', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_header_panel',
            'priority'  => 20,
        ));
        
        /**
         * Header Layouts Heading
         * 
         */
        $wp_customize->add_setting( 'header_style_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
    

        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'header_style_settings_header', array(
                'label' => esc_html__( 'Style', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_header_style_section',
                'settings'  => 'header_style_settings_header',
                'type'  => 'section-heading',
            ))
        );

        //header box shadow option
        $wp_customize->add_setting( 'header_bottom_box_shadow', array(
            'default' => 'hide',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'header_bottom_box_shadow', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_header_style_section',
            'label'     => esc_html__( 'Bottom box shadow', 'the-styled-blog' ),
            'choices'   => array(
                'show' => esc_html__( 'Show', 'the-styled-blog' ),
                'hide' => esc_html__( 'Hide', 'the-styled-blog' )
            ),
        ));

        // header background property
        $wp_customize->add_setting( 'header_background', array(
            'default'   => json_encode(array(
                'type'  => 'gradient',
                'solid' => null,
                'gradient'  => 'linear-gradient(135deg,rgb(254,254,254) 0%,rgba(160,85,230,0.2) 100%)',
                'image'     => array( 'media_id' => 0, 'media_url' => '' )
            )),
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Color_Image_Group_Control( $wp_customize, 'header_background', array(
                'label'	      => esc_html__( 'Background Setting', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_style_section',
                'settings'    => 'header_background'
            ))
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_header_style_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_header_style_info', array(
                'label'	      => esc_html__( 'For more layouts and settings', 'the-styled-blog' ),
                'description' => esc_html__( '3 header layouts, sidebar toggle and more options available in pro.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_style_section',
                'settings'    => 'site_header_style_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );

        /**
         * Menu Options Section
         * 
         * panel - the_styled_blog_header_panel
         */
        $wp_customize->add_section( 'the_styled_blog_header_menu_option_section', array(
            'title' => esc_html__( 'Menu Options', 'the-styled-blog' ),
            'panel' => 'the_styled_blog_header_panel',
            'priority'  => 30,
        ));

        /**
         * Header menu hover effect
         * 
         */
        $wp_customize->add_setting( 'header_menu_hover_effect', array(
            'default' => 'none',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'header_menu_hover_effect', array(
            'type'      => 'select',
            'section'   => 'the_styled_blog_header_menu_option_section',
            'label'     => __( 'Menu hover effect', 'the-styled-blog' ),
            'choices'   => array(
                'default' => esc_html__( 'Default', 'the-styled-blog' ),
                'none' => esc_html__( 'None', 'the-styled-blog' )
            ),
        ));

        /**
         * Header Menu Responsive Tab
         * 
         */
        $wp_customize->add_setting( 'header_menu_responsive_tabs_settings_header', array(
            'default'           => 'desktop',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Tab_Control( $wp_customize, 'header_menu_responsive_tabs_settings_header', array(
                'section'     => 'the_styled_blog_header_menu_option_section',
                'settings'    => 'header_menu_responsive_tabs_settings_header',
                'choices'   => array(
                    array(
                        'label' => esc_html__( 'Desktop', 'the-styled-blog' ),
                        'controls_hide' => array(
                            'responsive_header_menu_toggle_button_colors_settings_header',
                            'header_menu_toggle_button_color',
                            'header_menu_toggle_background_color'
                        ),
                        'controls' => array(
                            'header_menu_colors_settings_header',
                            'header_menu_font_color',
                            'header_active_menu_colors_settings_header',
                            'header_active_menu_font_color',
                            'header_menu_typo_settings_header',
                            'header_menu_typography'
                        )
                    ),
                    array(
                        'label' => esc_html__( 'Mobile', 'the-styled-blog' ),
                        'controls' => array(
                            'responsive_header_menu_toggle_button_colors_settings_header',
                            'header_menu_toggle_button_color',
                            'header_menu_toggle_background_color'
                        ),
                        'controls_hide' => array(
                            'header_menu_colors_settings_header',
                            'header_menu_font_color',
                            'header_active_menu_colors_settings_header',
                            'header_active_menu_font_color',
                            'header_menu_typo_settings_header',
                            'header_menu_typography'
                        )
                    )
                )
            ))
        );

        /**
         * Responsive Header Menu Toggle Button Colors Heading
         * 
         */
        $wp_customize->add_setting( 'responsive_header_menu_toggle_button_colors_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'responsive_header_menu_toggle_button_colors_settings_header', array(
                'label'	      => esc_html__( 'Toggle Button Colors', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_menu_option_section',
                'settings'    => 'responsive_header_menu_toggle_button_colors_settings_header',
                'type'        => 'section-heading',
                'active_callback'   => function() { return false; }
            ))
        );

        // Menu toggle button background color
        $wp_customize->add_setting( 'header_menu_toggle_button_color', array(
            'default'       => '#000000',
            'sanitize_callback' => 'the_styled_blog_sanitize_array',
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Color_Picker_Control( $wp_customize, 'header_menu_toggle_button_color', array(
                'label'     => esc_html__( 'Color', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_header_menu_option_section',
                'settings'  => 'header_menu_toggle_button_color',
                'active_callback'   => function() { return false; }
            ))
        );

        // Menu toggle button background color
        $wp_customize->add_setting( 'header_menu_toggle_background_color', array(
            'default'       => '#ffffff',
            'sanitize_callback' => 'the_styled_blog_sanitize_array',
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Color_Picker_Control( $wp_customize, 'header_menu_toggle_background_color', array(
                'label'     => esc_html__( 'Background Color', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_header_menu_option_section',
                'settings'  => 'header_menu_toggle_background_color',
                'active_callback'   => function() { return false; }
            ))
        );

        /**
         * Header Menu Colors Heading
         * 
         */
        $wp_customize->add_setting( 'header_menu_colors_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'header_menu_colors_settings_header', array(
                'label'	      => esc_html__( 'Colors', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_menu_option_section',
                'settings'    => 'header_menu_colors_settings_header'
            ))
        );

        // header menu font color and hover color
        $wp_customize->add_setting( 'header_menu_font_color', array(
            'default'   => array( 'color'   => null, 'hover'   => null ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Color_Group_Picker_Control( $wp_customize, 'header_menu_font_color', array(
                'label'     => esc_html__( 'Color / Hover Color', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_header_menu_option_section',
                'settings'  => 'header_menu_font_color',
            ))
        );
        
        /**
         * Header Active Menu Colors Heading
         * 
         */
        $wp_customize->add_setting( 'header_active_menu_colors_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'header_active_menu_colors_settings_header', array(
                'label'	      => esc_html__( 'Active Menu Colors', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_menu_option_section',
                'settings'    => 'header_active_menu_colors_settings_header'
            ))
        );
        
        // Header active menu color
        $wp_customize->add_setting( 'header_active_menu_font_color', array(
            'sanitize_callback' => 'the_styled_blog_sanitize_array',
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Color_Picker_Control( $wp_customize, 'header_active_menu_font_color', array(
                'label'     => esc_html__( 'Color', 'the-styled-blog' ),
                'section'   => 'the_styled_blog_header_menu_option_section',
                'settings'  => 'header_active_menu_font_color'
            ))
        );
        
        /**
         * Header Menu Typography Heading
         * 
         */
        $wp_customize->add_setting( 'header_menu_typo_settings_header', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'header_menu_typo_settings_header', array(
                'label'	      => esc_html__( 'Typography ', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_menu_option_section',
                'settings'    => 'header_menu_typo_settings_header'
            ))
        );

        // Add the `header text` typography settings.
        $wp_customize->add_setting( 'header_menu_font_family', array( 'default' => 'Montserrat',  'sanitize_callback' => 'sanitize_text_field' ) );
        $wp_customize->add_setting( 'header_menu_font_weight', array( 'default' => '700',    'sanitize_callback' => 'absint' ) );
        $wp_customize->add_setting( 'header_menu_font_style',  array( 'default' => 'normal', 'sanitize_callback' => 'sanitize_key') );
        $wp_customize->add_setting( 'header_menu_font_size',   array( 'default' => '15',     'sanitize_callback' => 'absint' ) );
        $wp_customize->add_setting( 'header_menu_line_height', array( 'default' => '16',     'sanitize_callback' => 'absint' ) );

        // Add the `menu` typography control.
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Typography_Control( $wp_customize, 'header_menu_typography',
                array(
                    'label' => __( 'Typography', 'the-styled-blog' ),
                    'section'     => 'the_styled_blog_header_menu_option_section',
                    'initial'     => true,
                    'settings'    => array(
                        'family'      => 'header_menu_font_family',
                        'weight'      => 'header_menu_font_weight',
                        'style'       => 'header_menu_font_style',
                        'size'        => 'header_menu_font_size',
                        'line_height' => 'header_menu_line_height'
                    )
                )
            )
        );

        // upgrade info box
        $wp_customize->add_setting( 'site_menu_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_menu_info', array(
                'label'	      => esc_html__( 'For more settings', 'the-styled-blog' ),
                'description' => esc_html__( 'More colors options available in pro.', 'the-styled-blog' ),
                'section'     => 'the_styled_blog_header_menu_option_section',
                'settings'    => 'site_menu_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_header_options_section', 10 );
endif;