<?php
/**
 * Footer Three Column Panel
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
if( !function_exists( 'the_styled_blog_customizer_footer_three_column_panel' ) ) :
    /**
     * Register footer three columns section settings
     * 
     */
    function the_styled_blog_customizer_footer_three_column_panel( $wp_customize ) {
        /**
         * Bottom Three Column Section
         * 
         * panel - the_styled_blog_frontpage_sections_panel
         */
        $wp_customize->add_section( 'footer_three_column_section', array(
            'title' => esc_html__( 'Footer Three Column', 'the-styled-blog' ),
            'priority'  => 50
        ));

        // upgrade info box
        $wp_customize->add_setting( 'site_three_column_info', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Info_Box_Control( $wp_customize, 'site_three_column_info', array(
                'label'	      => esc_html__( 'For more settings', 'the-styled-blog' ),
                'description' => esc_html__( 'More post count, custom column header title field.', 'the-styled-blog' ),
                'section'     => 'footer_three_column_section',
                'settings'    => 'site_three_column_info',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'View Premium', 'the-styled-blog' ),
                        'url'   => esc_url( '//blazethemes.com/theme/the-styled-blog-pro' )
                    )
                )
            ))
        );
        
        /**
         * Column One Heading Settings
         * 
         */
        $wp_customize->add_setting( 'footer_column_one_header_settings', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'footer_column_one_header_settings', array(
                'label'	      => esc_html__( 'Column One Section', 'the-styled-blog' ),
                'section'     => 'footer_three_column_section',
                'settings'    => 'footer_column_one_header_settings'
            ))
        );

        /**
         * Column one count
         * 
         */
        $wp_customize->add_setting( 'footer_column_one_count', array(
            'default'        => 3,
            'sanitize_callback' => 'absint',
        ));

        $wp_customize->add_control( 'footer_column_one_count', array(
            'label'    => esc_html__( 'Posts Count', 'the-styled-blog' ),
            'section'  => 'footer_three_column_section',		
            'type'     => 'number',
            'input_attrs'   => array(
                'min'   => 1,
                'step'  => 1,
                'max'   => 3
            )
        ));

        /**
         * Category select
         * 
         */
        $wp_customize->add_setting( 'footer_column_one_category', array(
            'default' => '',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'footer_column_one_category', array(
            'label' => esc_html__( 'Post category', 'the-styled-blog' ),
            'type' => 'select',
            'section' => 'footer_three_column_section',
            'choices' => the_styled_blog_get_select_categories_array()
        ));

        /**
         * Column Two Heading Settings
         * 
         */
        $wp_customize->add_setting( 'footer_column_two_header_settings', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'footer_column_two_header_settings', array(
                'label'	      => esc_html__( 'Column Two Section', 'the-styled-blog' ),
                'section'     => 'footer_three_column_section',
                'settings'    => 'footer_column_two_header_settings'
            ))
        );

        /**
         * Column two count
         * 
         */
        $wp_customize->add_setting( 'footer_column_two_count', array(
            'default'        => 3,
            'sanitize_callback' => 'absint',
        ));

        $wp_customize->add_control( 'footer_column_two_count', array(
            'label'    => esc_html__( 'Posts Count', 'the-styled-blog' ),
            'section'  => 'footer_three_column_section',		
            'type'     => 'number',
            'input_attrs'   => array(
                'min'   => 1,
                'step'  => 1,
                'max'   => 3
            )
        ));

        /**
         * Category select
         * 
         */
        $wp_customize->add_setting( 'footer_column_two_category', array(
            'default' => '',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'footer_column_two_category', array(
            'label' => esc_html__( 'Post category', 'the-styled-blog' ),
            'type' => 'select',
            'section' => 'footer_three_column_section',
            'choices' => the_styled_blog_get_select_categories_array()
        ));

        /**
         * Column Three Heading Settings
         * 
         */
        $wp_customize->add_setting( 'footer_column_three_header_settings', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'footer_column_three_header_settings', array(
                'label'	      => esc_html__( 'Column Three Section', 'the-styled-blog' ),
                'section'     => 'footer_three_column_section',
                'settings'    => 'footer_column_three_header_settings'
            ))
        );

        /**
         * Column three count
         * 
         */
        $wp_customize->add_setting( 'footer_column_three_count', array(
            'default'        => 3,
            'sanitize_callback' => 'absint',
        ));

        $wp_customize->add_control( 'footer_column_three_count', array(
            'label'    => esc_html__( 'Posts Count', 'the-styled-blog' ),
            'section'  => 'footer_three_column_section',		
            'type'     => 'number',
            'input_attrs'   => array(
                'min'   => 1,
                'step'  => 1,
                'max'   => 3
            )
        ));

        /**
         * Category select
         * 
         */
        $wp_customize->add_setting( 'footer_column_three_category', array(
            'default' => '',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'footer_column_three_category', array(
            'label' => esc_html__( 'Post category', 'the-styled-blog' ),
            'type' => 'select',
            'section' => 'footer_three_column_section',
            'choices' => the_styled_blog_get_select_categories_array()
        ));
        
        /**
         * Bottom Three Column Style Heading Settings
         * 
         */
        $wp_customize->add_setting( 'footer_three_column_style_header_settings', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Section_Heading_Control( $wp_customize, 'footer_three_column_style_header_settings', array(
                'label'	      => esc_html__( 'Style', 'the-styled-blog' ),
                'section'     => 'footer_three_column_section',
                'settings'    => 'footer_three_column_style_header_settings',
                'type'        => 'section-heading',
            ))
        );

        /**
         * Section width
         * 
         */
        $wp_customize->add_setting( 'footer_three_column_width', array(
            'default' => 'boxed-width',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'footer_three_column_width', array(
            'label' => esc_html__( 'Section Width', 'the-styled-blog' ),
            'type' => 'select',
            'section' => 'footer_three_column_section',
            'choices' => array(
                'full-width' => __( 'Full Width', 'the-styled-blog' ),
                'boxed-width' => __( 'Boxed Width', 'the-styled-blog' )
            ),
        ));

        /**
         * Section Visible option
         * 
         */
        $wp_customize->add_setting( 'footer_three_column_option', array(
            'default' => 'all',
            'sanitize_callback' => 'the_styled_blog_sanitize_select'
        ));
        
        $wp_customize->add_control( 'footer_three_column_option', array(
            'label' => esc_html__( 'Show section', 'the-styled-blog' ),
            'type' => 'select',
            'section' => 'footer_three_column_section',
            'choices' => array(
                'frontpage' => __( 'Show only on frontpage', 'the-styled-blog' ),
                'all'       => __( 'Show on frontpage and innerpages', 'the-styled-blog' ),
                'innerpages' => __( 'Show only on innerpages', 'the-styled-blog' ),
                'hide'      => __( 'Hide on all pages', 'the-styled-blog' )
            ),
        ));
        
        /**
         * Footer Three column Padding Settings
         * 
         */
        $wp_customize->add_setting( 'footer_three_column_padding', array( 
            'default' => array( 'desktop'   => array( 'top'=>'50px', 'right'	=> '50px', 'bottom'	=> '50px', 'left'	=> '50px' ), 'tablet'   => array( 'top'=>'50px', 'right'	=> '50px', 'bottom'	=> '50px', 'left'	=> '50px' ), 'smartphone'   => array( 'top'=>'50px', 'right'	=> '50px', 'bottom'	=> '50px', 'left'	=> '50px' ) ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Responsive_Box_Control( $wp_customize, 'footer_three_column_padding', array(
                'label'       => esc_html__( 'Padding', 'the-styled-blog' ),
                'section'     => 'footer_three_column_section',
                'settings'    => 'footer_three_column_padding'
            ))
        );

        // footer three column color and hover color
        $wp_customize->add_setting( 'footer_three_column_font_color', array(
            'default'   => array( 'color'   => null, 'hover'   => null ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array'
        ));
        $wp_customize->add_control(
            new The_Styled_Blog_WP_Color_Group_Picker_Control( $wp_customize, 'footer_three_column_font_color', array(
                'label'     => esc_html__( 'Color  / Hover Color', 'the-styled-blog' ),
                'section'   => 'footer_three_column_section',
                'settings'  => 'footer_three_column_font_color',
            ))
        );

        // footer three column background
        $wp_customize->add_setting( 'footer_three_column_background_color', array( 
            'default' => array( 'type' => 'gradient', 'solid'=> null, 'gradient' => 'linear-gradient(135deg,rgb(0,0,0) 0%,rgb(118,118,118) 100%)' ),
            'sanitize_callback' => 'the_styled_blog_sanitize_array'
        ));
        $wp_customize->add_control( 
            new The_Styled_Blog_WP_Advanced_Color_Group_Control( $wp_customize, 'footer_three_column_background_color', array(
                'label' => esc_html__( 'Background', 'the-styled-blog' ),
                'section'   => 'footer_three_column_section',
                'settings'  => 'footer_three_column_background_color',
            ))
        );
    }
    add_action( 'customize_register', 'the_styled_blog_customizer_footer_three_column_panel', 50 );
endif;