<?php
/**
 * Contains theme hooks and functions
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
if( !function_exists( 'the_styled_blog_scroll_to_top' ) ) :
    /**
     * Scroll to top fnc
     * 
     * @since 1.0.0
     */
    function the_styled_blog_scroll_to_top() {
        $scroll_to_top_option = get_theme_mod( 'scroll_to_top_option', true );
        if( ! $scroll_to_top_option ) return;
        $scroll_to_top_responsive_display = get_theme_mod( 'scroll_to_top_responsive_display', false );
        if( ! $scroll_to_top_responsive_display && wp_is_mobile() ) return;
        $scroll_to_top_align = get_theme_mod( 'scroll_to_top_align', 'align--right' );
    ?>
        <div id="the-styled-blog-scroll-to-top" class="<?php echo esc_attr( $scroll_to_top_align ); ?>" title="<?php echo esc_attr__( 'Back To Top', 'the-styled-blog' ); ?>">
            <span class="icon-holder"><i class="fas fa-chevron-up"></i></span>
        </div><!-- #the-styled-blog-scroll-to-top -->
    <?php
    }
    add_action( 'the_styled_blog_after_footer_hook', 'the_styled_blog_scroll_to_top' );
 endif;

 if( ! function_exists( 'the_styled_blog_single_author_box' ) ) :
    /**
     * Single author box
     * 
     */
    function the_styled_blog_single_author_box() {
        if( get_post_type() != 'post' ) return;

        if( get_theme_mod('single_post_author_box_option', true) ):
            ?>
            <div class="post-footer__author">
                <div class="author__avatar">
                    <?php echo wp_kses_post( get_avatar(get_the_author_meta('ID'), 125) ); ?>
                </div>
                <div class="author__info">
                    <h5 class="author-name"><?php echo esc_html( get_the_author() ); ?></h5>
                    <?php if( get_the_author_meta('description') ) { ?>
                        <p class="author-desc"><?php echo wp_kses_post( get_the_author_meta('description') ); ?></p>
                    <?php } ?>
                </div>
            </div>
            <?php
        endif;

    }
 endif;
 add_action( 'the_styled_blog_single_after_content', 'the_styled_blog_single_author_box' );

 if( ! function_exists( 'the_styled_blog_single_related_posts' ) ) :
    /**
     * Single related posts
     * 
     */
    function the_styled_blog_single_related_posts() {
        if( get_post_type() != 'post' ) return;
        if( is_single() ) :
            $single_post_related_posts_option = get_theme_mod( 'single_post_related_posts_option', true );
            if( ! $single_post_related_posts_option ) return;
            $related_posts_title = get_theme_mod( 'single_post_related_posts_title', esc_html__( 'Related Posts', 'the-styled-blog' ) );
            $post_count = get_theme_mod( 'single_post_related_posts_count', 3 );
        else :
            $archive_post_related_posts_responsive_display = get_theme_mod( 'archive_post_related_posts_responsive_display', false );
            if( ! $archive_post_related_posts_responsive_display && wp_is_mobile() ) return;
            $archive_post_related_posts_option = get_theme_mod( 'archive_post_related_posts_option', true );
            $archive_posts_layout = get_theme_mod( 'archive_posts_layout', 'grid-layout' );
            if( ! $archive_post_related_posts_option || $archive_posts_layout === 'blog-masonry' ) return;
            $related_posts_title = get_theme_mod( 'archive_post_related_posts_title', esc_html__( 'Related Posts', 'the-styled-blog' ) );
            $post_count = get_theme_mod( 'archive_post_related_posts_count', 3 );
        endif;
        $related_posts_args = array(
            'posts_per_page'   => absint( $post_count ),
            'post__not_in'  => array( get_the_ID() )
        );
        $current_post_categories = get_the_category(get_the_ID());
        if( $current_post_categories ) :
            foreach( $current_post_categories as $current_post_cat ) :
                $query_cats[] =  $current_post_cat->term_id;
            endforeach;
            $related_posts_args['category__in'] = $query_cats;
        endif;
        $related_posts = new WP_Query( $related_posts_args );
        if( ! $related_posts->have_posts() ) return;
  ?>
            <div class="single-related-posts-section">
                <?php
                    if( $related_posts_title ) echo '<div class="center-line-title -large -mb-2"><h5>' .esc_html( $related_posts_title ). '</h5></div>';
                        echo '<div class="single-related-posts-wrap">';
                            while( $related_posts->have_posts() ) : $related_posts->the_post();
                        ?>
                                <article post-id="post-<?php the_ID(); ?>" class="bmm-post post-card">
                                    <div class="post-thumb-wrap">
                                        <?php
                                            if( has_post_thumbnail() ) {
                                            ?>
                                                <div class="bmm-post-thumb">
                                                    <a href="<?php the_permalink(); ?>">
                                                        <?php 
                                                            the_post_thumbnail('the-styled-blog-grid');
                                                        ?>
                                                    </a>
                                                </div>
                                        <?php } ?>
                                    </div>
                                    <div class="card__content">
                                        <?php
                                            $categories = get_the_category( get_the_ID() );
                                            if( $categories ) {
                                                echo '<div class="bmm-post-cats-wrap bmm-post-meta-item">';
                                                $count = 0;
                                                foreach( $categories as $category ) :
                                                    echo '<span class="bmm-post-cat post-cat-'.absint( $category->term_id ).'"><a href="'.esc_url( get_term_link( $category->term_id ) ).'">'.esc_html( $category->name ).'</a></span>';
                                                    if( $count > 0 ) break;
                                                    $count++;
                                                endforeach;
                                                echo '</div>';
                                            }
                                        ?>
                                        <div class="bmm-post-title">
                                            <a class="card__content-title" href="<?php the_permalink(); ?>">
                                                <?php the_title(); ?>
                                            </a>
                                        </div>
                                    </div>
                                </article>
                        <?php
                            endwhile;
                        echo '</div>';
                ?>
            </div>
    <?php
    }
 endif;
 add_action( 'the_styled_blog_single_post_footer_hook', 'the_styled_blog_single_related_posts' );
 $archive_posts_layout = get_theme_mod( 'archive_posts_layout', 'grid-layout' );
 if( $archive_posts_layout != 'blog-masonry' ) add_action( 'the_styled_blog_archive_post_footer_hook', 'the_styled_blog_single_related_posts' );

if( ! function_exists( 'the_styled_blog_pagination_fnc' ) ) :
    /**
     * Renders pagination
     * 
     */
    function the_styled_blog_pagination_fnc() {
        if( is_null( paginate_links() ) ) {
            return;
        }
        $pagination_type = get_theme_mod( 'archive_pagination_type', 'pagination' );
        switch( $pagination_type ) {
            case 'ajax' : echo '<div class="the-styled-blog-ajax-loader-button"><button class="the-styled-blog-load-more btn -normal load-more-btn">' .esc_html( get_theme_mod( 'archive_ajax_button_label', esc_html__( 'Load more', 'the-styled-blog' ) ) ). '</button></div>';
                    break;
            default : echo '<div class="pagination">' .wp_kses_post( paginate_links( array( 'prev_text' => '<i class="fas fa-chevron-left"></i>', 'next_text' => '<i class="fas fa-chevron-right"></i>', 'type' => 'list' ) ) ). '</div>';
                    break;
        }
    }
    add_action( 'the_styled_blog_pagination_link_hook', 'the_styled_blog_pagination_fnc' );
 endif;