<?php
/**
 * Handle the wigets files and hooks
 * 
 * @package The Styled Blog
 * 
 */
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function the_styled_blog_widgets_init() {
	// default sidebar
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'the-styled-blog' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'the-styled-blog' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<div class="center-line-title"><h5 class="widget-title">',
			'after_title'   => '</h5></div>',
		)
	);

	if ( class_exists( 'WooCommerce' ) ) {
		// shop sidebar
		register_sidebar(
			array(
				'name'          => esc_html__( 'Shop Sidebar', 'the-styled-blog' ),
				'id'            => 'shop-sidebar',
				'description'   => esc_html__( 'Add widgets here.', 'the-styled-blog' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<div class="center-line-title"><h5 class="widget-title">',
				'after_title'   => '</h5></div>',
			)
		);	
	}

	// footer sidebars
	register_sidebars( 4, array(
			'name'          => esc_html__( 'Footer Column %d', 'the-styled-blog' ),
			'id'            => 'footer-column',
			'description'   => esc_html__( 'Add widgets here.', 'the-styled-blog' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<div class="center-line-title"><h5 class="widget-title">',
			'after_title'   => '</h5></div>',
		)
	);

    // Register custom widgets
    register_widget( 'The_Styled_Blog_Category_Collection_Widget' ); // category collection widget
	register_widget( 'The_Styled_Blog_Posts_List_Widget' ); // posts list widget
	register_widget( 'The_Styled_Blog_Author_Info_Widget' ); // author widget
	register_widget( 'The_Styled_Blog_Social_Icons_Widget' ); // social icons widget
	register_widget( 'The_Styled_Blog_Widget_Title_Widget' ); // widget title widget
}
add_action( 'widgets_init', 'the_styled_blog_widgets_init' );

// includes files
require THE_STYLED_BLOG_INCLUDES_PATH .'widgets/widget-fields.php';
require THE_STYLED_BLOG_INCLUDES_PATH .'widgets/category-collection.php';
require THE_STYLED_BLOG_INCLUDES_PATH .'widgets/posts-list.php';
require THE_STYLED_BLOG_INCLUDES_PATH .'widgets/author-info.php';
require THE_STYLED_BLOG_INCLUDES_PATH .'widgets/social-icons.php';
require THE_STYLED_BLOG_INCLUDES_PATH .'widgets/widget-title.php';

function the_styled_blog_widget_scripts($hook) {
    if( $hook !== "widgets.php" ) {
        return;
    }
    wp_enqueue_style( 'the-styled-blog-widget', get_template_directory_uri() . '/inc/widgets/assets/widgets.css', array(), THE_STYLED_BLOG_VERSION );

	wp_enqueue_media();
	wp_enqueue_script( 'the-styled-blog-widget', get_template_directory_uri() . '/inc/widgets/assets/widgets.js', array( 'jquery' ), THE_STYLED_BLOG_VERSION, true );
}
add_action( 'admin_enqueue_scripts', 'the_styled_blog_widget_scripts' );