<?php
/**
 * Header Template - layout one
 * 
 * @package The Styled Blog
 * @since 1.0.0
 */
?>
<header id="main-header" class="theme-default">
    <?php if( get_theme_mod( 'header_search_option', true ) ) { ?>
        <div id="search-box">
            <div class="container">
                <?php echo get_search_form(); ?>
            </div>
        </div>
    <?php } ?>
    <div class="container">
        <div class="header-wrapper">
            <div class="header_logo_wrap">
                <?php the_custom_logo(); ?>
                <div class="layout_one_title">
                    <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                    <?php 
                    $the_styled_blog_description = get_bloginfo( 'description', 'display' );
                    if ( $the_styled_blog_description || is_customize_preview() ) :
                        ?>
                        <p class="site-description"><?php echo wp_kses_post( $the_styled_blog_description ); ?></p>
                        <?php
                        endif;
                    ?>
                </div>
            </div>
            <div class="menu_nav_content">
                <nav id="site-navigation">
                    <button id="menu-toggle" class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><i class="fas fa-bars"></i><span class="menu_txt"><?php esc_html_e('MENU','the-styled-blog') ?></span></button>
                    <?php
                        if( has_nav_menu( 'menu-1' ) ) :
                            wp_nav_menu(
                                array(
                                    'theme_location' => 'menu-1',
                                    'menu_id'        => 'primary-menu',
                                )
                            );
                        else :
                            if ( is_user_logged_in() && current_user_can( 'edit_theme_options' ) ) {
                               ?>
                                  <a href="<?php echo esc_url( admin_url( '/nav-menus.php?action=locations' ) ); ?>"><?php esc_html_e( 'Setup Menu', 'the-styled-blog' ); ?></a>
                               <?php
                            }
                        endif;
                    ?>
                </nav>
            </div>
            <div class="header__icon-group">
                <?php 
                    if( get_theme_mod( 'header_search_option', true ) ) {
                        echo '<a href="#" id="search"><i class="fas fa-search"></i></a>';
                    }

                    if( get_theme_mod( 'header_social_option', true ) ) :
                        $social_icons_target = get_theme_mod( 'social_icons_target', '_blank' );
                        $social_icons = get_theme_mod( 'social_icons', json_encode( array(
                                array(
                                    'icon_class'    => esc_attr( 'fab fa-linkedin-in' ),
                                    'icon_url'  => '',
                                    'item_option'   => 'show'
                                ),
                                array(
                                    'icon_class'    => esc_attr( 'fab fa-twitter' ),
                                    'icon_url'  => '',
                                    'item_option'   => 'show'
                                ),
                                array(
                                    'icon_class'    => esc_attr( 'fab fa-vimeo-v' ),
                                    'icon_url'  => '',
                                    'item_option'   => 'show'
                                ),
                                array(
                                    'icon_class'    => esc_attr( 'fab fa-instagram' ),
                                    'icon_url'  => '',
                                    'item_option'   => 'show'
                                )
                            ))
                        );
                        $social_icons_docoded = json_decode( $social_icons );
                ?>
                        <div class="social">
                            <?php
                                foreach( $social_icons_docoded as $social_icon ) {
                                    $icon_value = $social_icon->icon_class;
                                    $icon_link = $social_icon->icon_url;
                                    if( $social_icon->item_option === 'show' ) echo '<a href="' .esc_url( $icon_link ). '" target="' .esc_attr( $social_icons_target ). '"><i class="' .esc_attr( $icon_value ). '"></i></a>';
                                }
                            ?>
                            <a id="mobile-menu-controller" href="#"><i class="fas fa-bars"></i></a>
                        </div>
                <?php
                    endif;
                ?>
            </div>
        </div>
    </div>
</header>